@@ -57,16 +57,16 @@ var NAVTREE =
 var NAVTREEINDEX =
 [
 ".html",
-"classSteinberg_1_1Vst_1_1AGainController.html#a4dae123b5697706651d9ff20c9614f63",
-"classSteinberg_1_1Vst_1_1NoteExpressionSynth_1_1Controller.html#accb2b76127645a7a8ec171c7b220ce8d",
-"classSteinberg_1_1Vst_1_1VoiceProcessor.html#aa0f1925c785d52e33d430e24a55cc7e4",
-"classSteinberg_1_1Vst_1_1mda_1_1DX10Controller.html#a699787679fa0c570221c8667007b8d31",
-"classSteinberg_1_1Vst_1_1mda_1_1DubDelayProcessor.html#a272e5d4c8e24f012573f9f5b11f7f569",
-"classSteinberg_1_1Vst_1_1mda_1_1LeslieProcessor.html#a11784160b1e993a66a2166bfc11a4359",
-"classSteinberg_1_1Vst_1_1mda_1_1RePsychoProcessor.html#a35aa3fed88ff6cfb7898384d9e608277",
-"classSteinberg_1_1Vst_1_1mda_1_1SubSynthController.html#acbd0bddc8a0b209adfe907e208f1ff8c",
-"doc_8h.html",
-"legacymidiccout_2source_2version_8h.html#a959cc5c14daa39d176d88fffd211aa6c",
+"classSteinberg_1_1Vst_1_1AGainController.html#a813cbf9dee7a64708f56160974dd37b0",
+"classSteinberg_1_1Vst_1_1NoteExpressionSynth_1_1Controller.html#aeb78d794ce0bc5812c526a1cc2083d5d",
+"classSteinberg_1_1Vst_1_1VoiceProcessor.html#aa86ea8cc7dd3cf5f2033f261daec4165",
+"classSteinberg_1_1Vst_1_1mda_1_1DX10Controller.html#a7d9642a22f48a9f5597bd1659744d882",
+"classSteinberg_1_1Vst_1_1mda_1_1DubDelayProcessor.html#a3026090cef033b689dc36c5f122924f9",
+"classSteinberg_1_1Vst_1_1mda_1_1LeslieProcessor.html#a16b31222df0f65f2f673cb819279d694",
+"classSteinberg_1_1Vst_1_1mda_1_1RePsychoProcessor.html#a46336872a13f7624153028a309558b97",
+"classSteinberg_1_1Vst_1_1mda_1_1SubSynthController.html#af178bffd48e73128237191204ea01c41",
+"editorhost_2source_2usediids_8cpp.html",
+"legacymidiccout_2source_2version_8h.html#aa863825ce130d257c1ba798e4e639d67",
 "mdaDeEsserController_8h.html",
 "note__expression__text_2source_2plugentry_8cpp.html#a580d3236cf2654394fd9dda85651efc0",
 "syncdelayids_8h.html#aaf105ae5beaca1dee30ae54530691fcea57a371feb983eb7350939ef1aab87090"
