@@ -9,20 +9,20 @@ var NAVTREEINDEX0 =
 ".html":[2,0,0,1],
 ".html":[1,0,0,1],
 ".html":[1,0,1],
-"VSTInterAppAudioAppDelegate_8h.html":[3,0,282],
-"VSTInterAppAudioAppDelegate_8mm.html":[3,0,283],
-"VSTInterAppAudioHostUIControllerViewController_8h.html":[3,0,284],
-"VSTInterAppAudioHostUIControllerViewController_8mm.html":[3,0,285],
-"adelay_2source_2factory_8cpp.html":[3,0,36],
-"adelay_2source_2factory_8cpp.html#a580d3236cf2654394fd9dda85651efc0":[3,0,36,0],
-"adelay_2source_2version_8h.html":[3,0,269],
-"adelay_2source_2version_8h.html#a642cf2d637621b344ca826ba26e3da52":[3,0,269,2],
-"adelay_2source_2version_8h.html#a7b9ca76cb4cc59f027ddabbe5f3f2118":[3,0,269,5],
-"adelay_2source_2version_8h.html#a9278205f41909b317803db604ed1075d":[3,0,269,1],
-"adelay_2source_2version_8h.html#a959cc5c14daa39d176d88fffd211aa6c":[3,0,269,4],
-"adelay_2source_2version_8h.html#aa863825ce130d257c1ba798e4e639d67":[3,0,269,6],
-"adelay_2source_2version_8h.html#ab3aa50bfa1df9fe473bf9202c2bff0cd":[3,0,269,3],
-"adelay_2source_2version_8h.html#adb58dbe9424bfe0a2e594a5e6399c3e2":[3,0,269,0],
+"VSTInterAppAudioAppDelegate_8h.html":[3,0,281],
+"VSTInterAppAudioAppDelegate_8mm.html":[3,0,282],
+"VSTInterAppAudioHostUIControllerViewController_8h.html":[3,0,283],
+"VSTInterAppAudioHostUIControllerViewController_8mm.html":[3,0,284],
+"adelay_2source_2factory_8cpp.html":[3,0,35],
+"adelay_2source_2factory_8cpp.html#a580d3236cf2654394fd9dda85651efc0":[3,0,35,0],
+"adelay_2source_2version_8h.html":[3,0,268],
+"adelay_2source_2version_8h.html#a642cf2d637621b344ca826ba26e3da52":[3,0,268,2],
+"adelay_2source_2version_8h.html#a7b9ca76cb4cc59f027ddabbe5f3f2118":[3,0,268,5],
+"adelay_2source_2version_8h.html#a9278205f41909b317803db604ed1075d":[3,0,268,1],
+"adelay_2source_2version_8h.html#a959cc5c14daa39d176d88fffd211aa6c":[3,0,268,4],
+"adelay_2source_2version_8h.html#aa863825ce130d257c1ba798e4e639d67":[3,0,268,6],
+"adelay_2source_2version_8h.html#ab3aa50bfa1df9fe473bf9202c2bff0cd":[3,0,268,3],
+"adelay_2source_2version_8h.html#adb58dbe9424bfe0a2e594a5e6399c3e2":[3,0,268,0],
 "adelaycontroller_8cpp.html":[3,0,0],
 "adelaycontroller_8cpp.html#ad4b1aebf3c139f29c168a7b0c7513b89":[3,0,0,0],
 "adelaycontroller_8h.html":[3,0,1],
@@ -31,33 +31,33 @@ var NAVTREEINDEX0 =
 "adelayids_8h.html#aaf105ae5beaca1dee30ae54530691fcea7d4228d4da0ae0131ef1783f79526104":[3,0,2,0],
 "adelayprocessor_8cpp.html":[3,0,3],
 "adelayprocessor_8h.html":[3,0,4],
-"again_2source_2version_8h.html":[3,0,270],
-"again_2source_2version_8h.html#a642cf2d637621b344ca826ba26e3da52":[3,0,270,2],
-"again_2source_2version_8h.html#a7b9ca76cb4cc59f027ddabbe5f3f2118":[3,0,270,5],
-"again_2source_2version_8h.html#a9278205f41909b317803db604ed1075d":[3,0,270,1],
-"again_2source_2version_8h.html#a959cc5c14daa39d176d88fffd211aa6c":[3,0,270,4],
-"again_2source_2version_8h.html#aa863825ce130d257c1ba798e4e639d67":[3,0,270,6],
-"again_2source_2version_8h.html#ab3aa50bfa1df9fe473bf9202c2bff0cd":[3,0,270,3],
-"again_2source_2version_8h.html#adb58dbe9424bfe0a2e594a5e6399c3e2":[3,0,270,0],
+"again_2source_2version_8h.html":[3,0,269],
+"again_2source_2version_8h.html#a642cf2d637621b344ca826ba26e3da52":[3,0,269,2],
+"again_2source_2version_8h.html#a7b9ca76cb4cc59f027ddabbe5f3f2118":[3,0,269,5],
+"again_2source_2version_8h.html#a9278205f41909b317803db604ed1075d":[3,0,269,1],
+"again_2source_2version_8h.html#a959cc5c14daa39d176d88fffd211aa6c":[3,0,269,4],
+"again_2source_2version_8h.html#aa863825ce130d257c1ba798e4e639d67":[3,0,269,6],
+"again_2source_2version_8h.html#ab3aa50bfa1df9fe473bf9202c2bff0cd":[3,0,269,3],
+"again_2source_2version_8h.html#adb58dbe9424bfe0a2e594a5e6399c3e2":[3,0,269,0],
 "again_8cpp.html":[3,0,5],
 "again_8h.html":[3,0,6],
-"again__auv3_2audiounitconfig_8h.html":[3,0,20],
-"again__auv3_2audiounitconfig_8h.html#a270b560b1a8891081787ed0ba81c6f35":[3,0,20,12],
-"again__auv3_2audiounitconfig_8h.html#a3cac5ff5fa6d00c89872bd159c33e552":[3,0,20,10],
-"again__auv3_2audiounitconfig_8h.html#a4019d8ce3bdbd1f14eb6c6429cb097f9":[3,0,20,6],
-"again__auv3_2audiounitconfig_8h.html#a476caadf14c9cb14d70ae895e4c5047f":[3,0,20,1],
-"again__auv3_2audiounitconfig_8h.html#a52d31c2d5038d5bcc6c6fce79c4a4c62":[3,0,20,15],
-"again__auv3_2audiounitconfig_8h.html#a673df5bd51e1927c698e4934cae14c98":[3,0,20,5],
-"again__auv3_2audiounitconfig_8h.html#aa5487d926fdfe6333497df02061b0758":[3,0,20,0],
-"again__auv3_2audiounitconfig_8h.html#aa9b5ee2bd3eae06aa44950043b4ed2b0":[3,0,20,11],
-"again__auv3_2audiounitconfig_8h.html#aaf9e8ddda61d8ddd8ad10c507533643e":[3,0,20,14],
-"again__auv3_2audiounitconfig_8h.html#ab4c92ba5e6b1c1d97773bf0cc84125bc":[3,0,20,3],
-"again__auv3_2audiounitconfig_8h.html#abae7faa0480421761493fea8346c1587":[3,0,20,4],
-"again__auv3_2audiounitconfig_8h.html#ad8225b98baf3f9d12f5f22981f990d53":[3,0,20,8],
-"again__auv3_2audiounitconfig_8h.html#ad84fd3bf68b1aeebb32efab604f5dafd":[3,0,20,2],
-"again__auv3_2audiounitconfig_8h.html#aec608402638dd0120398bda1074a4eb2":[3,0,20,7],
-"again__auv3_2audiounitconfig_8h.html#af1327eb2e2055860752d5b164adc03cf":[3,0,20,9],
-"again__auv3_2audiounitconfig_8h.html#af51e79c5ec243a082686a9f441aefafa":[3,0,20,13],
+"again__auv3_2audiounitconfig_8h.html":[3,0,19],
+"again__auv3_2audiounitconfig_8h.html#a270b560b1a8891081787ed0ba81c6f35":[3,0,19,12],
+"again__auv3_2audiounitconfig_8h.html#a3cac5ff5fa6d00c89872bd159c33e552":[3,0,19,10],
+"again__auv3_2audiounitconfig_8h.html#a4019d8ce3bdbd1f14eb6c6429cb097f9":[3,0,19,6],
+"again__auv3_2audiounitconfig_8h.html#a476caadf14c9cb14d70ae895e4c5047f":[3,0,19,1],
+"again__auv3_2audiounitconfig_8h.html#a52d31c2d5038d5bcc6c6fce79c4a4c62":[3,0,19,15],
+"again__auv3_2audiounitconfig_8h.html#a673df5bd51e1927c698e4934cae14c98":[3,0,19,5],
+"again__auv3_2audiounitconfig_8h.html#aa5487d926fdfe6333497df02061b0758":[3,0,19,0],
+"again__auv3_2audiounitconfig_8h.html#aa9b5ee2bd3eae06aa44950043b4ed2b0":[3,0,19,11],
+"again__auv3_2audiounitconfig_8h.html#aaf9e8ddda61d8ddd8ad10c507533643e":[3,0,19,14],
+"again__auv3_2audiounitconfig_8h.html#ab4c92ba5e6b1c1d97773bf0cc84125bc":[3,0,19,3],
+"again__auv3_2audiounitconfig_8h.html#abae7faa0480421761493fea8346c1587":[3,0,19,4],
+"again__auv3_2audiounitconfig_8h.html#ad8225b98baf3f9d12f5f22981f990d53":[3,0,19,8],
+"again__auv3_2audiounitconfig_8h.html#ad84fd3bf68b1aeebb32efab604f5dafd":[3,0,19,2],
+"again__auv3_2audiounitconfig_8h.html#aec608402638dd0120398bda1074a4eb2":[3,0,19,7],
+"again__auv3_2audiounitconfig_8h.html#af1327eb2e2055860752d5b164adc03cf":[3,0,19,9],
+"again__auv3_2audiounitconfig_8h.html#af51e79c5ec243a082686a9f441aefafa":[3,0,19,13],
 "againaax_8cpp.html":[3,0,7],
 "againaax_8cpp.html#a08d8594ad5e5ada34107022d3a6e80ad":[3,0,7,5],
 "againaax_8cpp.html#a3df507746718c13e0db2b2eb888128e8":[3,0,7,4],
@@ -79,58 +79,56 @@ var NAVTREEINDEX0 =
 "againentry_8cpp.html#a8653c7346fb9d21f5079d10e95997efe":[3,0,11,7],
 "againentry_8cpp.html#aa2957643985a01da1edc5c69727584d1":[3,0,11,5],
 "againentry_8cpp.html#ad55a4f99f6b826bc06bf14e8d8473ca2":[3,0,11,8],
-"againentry__vst2_8cpp.html":[3,0,12],
-"againentry__vst2_8cpp.html#acea66abdb15a93b63dd7e2e7777d0271":[3,0,12,0],
-"againparamids_8h.html":[3,0,13],
-"againparamids_8h.html#adf764cbdea00d65edcd07bb9953ad2b7a9006dde2a6fcecd0d0f30fdcaec1ec16":[3,0,13,0],
-"againparamids_8h.html#adf764cbdea00d65edcd07bb9953ad2b7ac89effee4c5c335b71019bc4a4fa1133":[3,0,13,1],
-"againparamids_8h.html#adf764cbdea00d65edcd07bb9953ad2b7af4e2f2cc267406eb8c152ecab32fd088":[3,0,13,2],
-"againprocess_8h.html":[3,0,14],
-"againsidechain_8cpp.html":[3,0,15],
-"againsidechain_8h.html":[3,0,16],
-"againuimessagecontroller_8h.html":[3,0,17],
+"againparamids_8h.html":[3,0,12],
+"againparamids_8h.html#adf764cbdea00d65edcd07bb9953ad2b7a9006dde2a6fcecd0d0f30fdcaec1ec16":[3,0,12,0],
+"againparamids_8h.html#adf764cbdea00d65edcd07bb9953ad2b7ac89effee4c5c335b71019bc4a4fa1133":[3,0,12,1],
+"againparamids_8h.html#adf764cbdea00d65edcd07bb9953ad2b7af4e2f2cc267406eb8c152ecab32fd088":[3,0,12,2],
+"againprocess_8h.html":[3,0,13],
+"againsidechain_8cpp.html":[3,0,14],
+"againsidechain_8h.html":[3,0,15],
+"againuimessagecontroller_8h.html":[3,0,16],
 "annotated.html":[2,0],
-"audiohost_2source_2usediids_8cpp.html":[3,0,264],
-"audiohost_8cpp.html":[3,0,18],
-"audiohost_8cpp.html#ae1325efcce4a4b1b4ea52247f0a0a0c1":[3,0,18,0],
-"audiohost_8cpp.html#ae321ca2b045da80954622c101138b2b7":[3,0,18,1],
-"audiohost_8h.html":[3,0,19],
-"brownnoise_8h.html":[3,0,22],
-"channelcontext_2source_2plug_8cpp.html":[3,0,213],
-"channelcontext_2source_2plug_8h.html":[3,0,218],
-"channelcontext_2source_2plugcids_8h.html":[3,0,223],
-"channelcontext_2source_2plugcontroller_8cpp.html":[3,0,228],
-"channelcontext_2source_2plugcontroller_8h.html":[3,0,234],
-"channelcontext_2source_2plugentry_8cpp.html":[3,0,239],
-"channelcontext_2source_2plugentry_8cpp.html#a02a91b99caf79fb15c24d52d2df6c14a":[3,0,239,5],
-"channelcontext_2source_2plugentry_8cpp.html#a1075637db8f5731ef803159910f409f8":[3,0,239,1],
-"channelcontext_2source_2plugentry_8cpp.html#a22ccdd26647e8146eeb5a3cf4d6c251e":[3,0,239,4],
-"channelcontext_2source_2plugentry_8cpp.html#a580d3236cf2654394fd9dda85651efc0":[3,0,239,0],
-"channelcontext_2source_2plugentry_8cpp.html#a7668929ac981fa3b7c508e7578a3e357":[3,0,239,2],
-"channelcontext_2source_2plugentry_8cpp.html#a8e474a03994aa5c0ee4068ec2b3b7217":[3,0,239,6],
-"channelcontext_2source_2plugentry_8cpp.html#acafd164691a959e204ad34d63e0c4266":[3,0,239,3],
-"channelcontext_2source_2plugparamids_8h.html":[3,0,245],
-"channelcontext_2source_2plugparamids_8h.html#a99fb83031ce9923c84392b4e92f956b5a129fcb67ba283f51cacaf083b3ac2e46":[3,0,245,8],
-"channelcontext_2source_2plugparamids_8h.html#a99fb83031ce9923c84392b4e92f956b5a3069645a9a0942433240e2823d527536":[3,0,245,4],
-"channelcontext_2source_2plugparamids_8h.html#a99fb83031ce9923c84392b4e92f956b5a3eef4af72278a5ae9af5aa8023a7f5b4":[3,0,245,10],
-"channelcontext_2source_2plugparamids_8h.html#a99fb83031ce9923c84392b4e92f956b5a75e82f9be248b2e65cf81e33074ee84e":[3,0,245,7],
-"channelcontext_2source_2plugparamids_8h.html#a99fb83031ce9923c84392b4e92f956b5a8adb5c41ccf53f31999d2b7ba0cd4df0":[3,0,245,1],
-"channelcontext_2source_2plugparamids_8h.html#a99fb83031ce9923c84392b4e92f956b5a8f67e086bdde41003f9c5df719954159":[3,0,245,2],
-"channelcontext_2source_2plugparamids_8h.html#a99fb83031ce9923c84392b4e92f956b5a9ca40743cd40f2cca0c40092fe666e60":[3,0,245,5],
-"channelcontext_2source_2plugparamids_8h.html#a99fb83031ce9923c84392b4e92f956b5aa1303f6f7af3f6dd88adc2d8047da59a":[3,0,245,9],
-"channelcontext_2source_2plugparamids_8h.html#a99fb83031ce9923c84392b4e92f956b5aaac38d9210256461713326a614cea99e":[3,0,245,3],
-"channelcontext_2source_2plugparamids_8h.html#a99fb83031ce9923c84392b4e92f956b5ac7b803af7e706ee9b1436f9f77ed0766":[3,0,245,6],
-"channelcontext_2source_2plugparamids_8h.html#a99fb83031ce9923c84392b4e92f956b5af4e2f2cc267406eb8c152ecab32fd088":[3,0,245,0],
-"channelcontext_2source_2version_8h.html":[3,0,271],
-"channelcontext_2source_2version_8h.html#a642cf2d637621b344ca826ba26e3da52":[3,0,271,2],
-"channelcontext_2source_2version_8h.html#a7b9ca76cb4cc59f027ddabbe5f3f2118":[3,0,271,5],
-"channelcontext_2source_2version_8h.html#a9278205f41909b317803db604ed1075d":[3,0,271,1],
-"channelcontext_2source_2version_8h.html#a959cc5c14daa39d176d88fffd211aa6c":[3,0,271,4],
-"channelcontext_2source_2version_8h.html#aa863825ce130d257c1ba798e4e639d67":[3,0,271,6],
-"channelcontext_2source_2version_8h.html#ab3aa50bfa1df9fe473bf9202c2bff0cd":[3,0,271,3],
-"channelcontext_2source_2version_8h.html#adb58dbe9424bfe0a2e594a5e6399c3e2":[3,0,271,0],
-"cids_8h.html":[3,0,23],
-"cids_8h.html#ab3fb28675e9f2f42c0b9de8aac469a83":[3,0,23,0],
+"audiohost_2source_2usediids_8cpp.html":[3,0,263],
+"audiohost_8cpp.html":[3,0,17],
+"audiohost_8cpp.html#ae1325efcce4a4b1b4ea52247f0a0a0c1":[3,0,17,0],
+"audiohost_8cpp.html#ae321ca2b045da80954622c101138b2b7":[3,0,17,1],
+"audiohost_8h.html":[3,0,18],
+"brownnoise_8h.html":[3,0,21],
+"channelcontext_2source_2plug_8cpp.html":[3,0,212],
+"channelcontext_2source_2plug_8h.html":[3,0,217],
+"channelcontext_2source_2plugcids_8h.html":[3,0,222],
+"channelcontext_2source_2plugcontroller_8cpp.html":[3,0,227],
+"channelcontext_2source_2plugcontroller_8h.html":[3,0,233],
+"channelcontext_2source_2plugentry_8cpp.html":[3,0,238],
+"channelcontext_2source_2plugentry_8cpp.html#a02a91b99caf79fb15c24d52d2df6c14a":[3,0,238,5],
+"channelcontext_2source_2plugentry_8cpp.html#a1075637db8f5731ef803159910f409f8":[3,0,238,1],
+"channelcontext_2source_2plugentry_8cpp.html#a22ccdd26647e8146eeb5a3cf4d6c251e":[3,0,238,4],
+"channelcontext_2source_2plugentry_8cpp.html#a580d3236cf2654394fd9dda85651efc0":[3,0,238,0],
+"channelcontext_2source_2plugentry_8cpp.html#a7668929ac981fa3b7c508e7578a3e357":[3,0,238,2],
+"channelcontext_2source_2plugentry_8cpp.html#a8e474a03994aa5c0ee4068ec2b3b7217":[3,0,238,6],
+"channelcontext_2source_2plugentry_8cpp.html#acafd164691a959e204ad34d63e0c4266":[3,0,238,3],
+"channelcontext_2source_2plugparamids_8h.html":[3,0,244],
+"channelcontext_2source_2plugparamids_8h.html#a99fb83031ce9923c84392b4e92f956b5a129fcb67ba283f51cacaf083b3ac2e46":[3,0,244,8],
+"channelcontext_2source_2plugparamids_8h.html#a99fb83031ce9923c84392b4e92f956b5a3069645a9a0942433240e2823d527536":[3,0,244,4],
+"channelcontext_2source_2plugparamids_8h.html#a99fb83031ce9923c84392b4e92f956b5a3eef4af72278a5ae9af5aa8023a7f5b4":[3,0,244,10],
+"channelcontext_2source_2plugparamids_8h.html#a99fb83031ce9923c84392b4e92f956b5a75e82f9be248b2e65cf81e33074ee84e":[3,0,244,7],
+"channelcontext_2source_2plugparamids_8h.html#a99fb83031ce9923c84392b4e92f956b5a8adb5c41ccf53f31999d2b7ba0cd4df0":[3,0,244,1],
+"channelcontext_2source_2plugparamids_8h.html#a99fb83031ce9923c84392b4e92f956b5a8f67e086bdde41003f9c5df719954159":[3,0,244,2],
+"channelcontext_2source_2plugparamids_8h.html#a99fb83031ce9923c84392b4e92f956b5a9ca40743cd40f2cca0c40092fe666e60":[3,0,244,5],
+"channelcontext_2source_2plugparamids_8h.html#a99fb83031ce9923c84392b4e92f956b5aa1303f6f7af3f6dd88adc2d8047da59a":[3,0,244,9],
+"channelcontext_2source_2plugparamids_8h.html#a99fb83031ce9923c84392b4e92f956b5aaac38d9210256461713326a614cea99e":[3,0,244,3],
+"channelcontext_2source_2plugparamids_8h.html#a99fb83031ce9923c84392b4e92f956b5ac7b803af7e706ee9b1436f9f77ed0766":[3,0,244,6],
+"channelcontext_2source_2plugparamids_8h.html#a99fb83031ce9923c84392b4e92f956b5af4e2f2cc267406eb8c152ecab32fd088":[3,0,244,0],
+"channelcontext_2source_2version_8h.html":[3,0,270],
+"channelcontext_2source_2version_8h.html#a642cf2d637621b344ca826ba26e3da52":[3,0,270,2],
+"channelcontext_2source_2version_8h.html#a7b9ca76cb4cc59f027ddabbe5f3f2118":[3,0,270,5],
+"channelcontext_2source_2version_8h.html#a9278205f41909b317803db604ed1075d":[3,0,270,1],
+"channelcontext_2source_2version_8h.html#a959cc5c14daa39d176d88fffd211aa6c":[3,0,270,4],
+"channelcontext_2source_2version_8h.html#aa863825ce130d257c1ba798e4e639d67":[3,0,270,6],
+"channelcontext_2source_2version_8h.html#ab3aa50bfa1df9fe473bf9202c2bff0cd":[3,0,270,3],
+"channelcontext_2source_2version_8h.html#adb58dbe9424bfe0a2e594a5e6399c3e2":[3,0,270,0],
+"cids_8h.html":[3,0,22],
+"cids_8h.html#ab3fb28675e9f2f42c0b9de8aac469a83":[3,0,22,0],
 "classAGainUIMessageController.html":[2,0,3],
 "classEventListCheck.html":[2,0,4],
 "classEventListCheck.html#a13c4ecb2dba03d3cfb14ae0d2e7aa6f6":[2,0,4,3],
@@ -249,5 +247,7 @@ var NAVTREEINDEX0 =
 "classSteinberg_1_1Vst_1_1AGainController.html#a0c25846cfb4cee3a28d6446c4f324877":[2,0,0,1,9,15],
 "classSteinberg_1_1Vst_1_1AGainController.html#a267a3f7fb32c318d5a887bb666f6cc98":[2,0,0,1,9,18],
 "classSteinberg_1_1Vst_1_1AGainController.html#a272e5d4c8e24f012573f9f5b11f7f569":[2,0,0,1,9,6],
-"classSteinberg_1_1Vst_1_1AGainController.html#a30e212b4af962b3920c149f09f339555":[2,0,0,1,9,17]
+"classSteinberg_1_1Vst_1_1AGainController.html#a30e212b4af962b3920c149f09f339555":[2,0,0,1,9,17],
+"classSteinberg_1_1Vst_1_1AGainController.html#a4dae123b5697706651d9ff20c9614f63":[2,0,0,1,9,5],
+"classSteinberg_1_1Vst_1_1AGainController.html#a634ef43d3538409b98c1fc2cd5e494a0":[2,0,0,1,9,8]
 };
