@@ -1,7 +1,5 @@
 var NAVTREEINDEX1 =
 {
-"classSteinberg_1_1Vst_1_1AGainController.html#a4dae123b5697706651d9ff20c9614f63":[2,0,0,1,9,5],
-"classSteinberg_1_1Vst_1_1AGainController.html#a634ef43d3538409b98c1fc2cd5e494a0":[2,0,0,1,9,8],
 "classSteinberg_1_1Vst_1_1AGainController.html#a813cbf9dee7a64708f56160974dd37b0":[2,0,0,1,9,12],
 "classSteinberg_1_1Vst_1_1AGainController.html#a8c6c97d769c5adbee243cd5dc1746e84":[2,0,0,1,9,19],
 "classSteinberg_1_1Vst_1_1AGainController.html#a9228db732b48ece8b5b734e69b979d10":[2,0,0,1,9,9],
@@ -50,19 +48,19 @@ var NAVTREEINDEX1 =
 "classSteinberg_1_1Vst_1_1EditorSizeController.html#afb51d7f8c0a75b05503418a83a8e64ca":[2,0,0,1,19,6],
 "classSteinberg_1_1Vst_1_1HostCheckerController.html":[2,0,0,1,20],
 "classSteinberg_1_1Vst_1_1HostCheckerController.html#a03c47a40142ada389fa7df3ab00f75c8":[2,0,0,1,20,44],
-"classSteinberg_1_1Vst_1_1HostCheckerController.html#a06f291cb573e68c068f1575530e558a9":[2,0,0,1,20,63],
+"classSteinberg_1_1Vst_1_1HostCheckerController.html#a06f291cb573e68c068f1575530e558a9":[2,0,0,1,20,64],
 "classSteinberg_1_1Vst_1_1HostCheckerController.html#a07afea77ec32591cdc9647baf9e5341c":[2,0,0,1,20,38],
-"classSteinberg_1_1Vst_1_1HostCheckerController.html#a0e0358aa35e63cb6a96d4738b86a4cb2":[2,0,0,1,20,60],
+"classSteinberg_1_1Vst_1_1HostCheckerController.html#a0e0358aa35e63cb6a96d4738b86a4cb2":[2,0,0,1,20,61],
 "classSteinberg_1_1Vst_1_1HostCheckerController.html#a170e3042a5e695227c6931fba321debb":[2,0,0,1,20,21],
-"classSteinberg_1_1Vst_1_1HostCheckerController.html#a182625d2b02683f36ec4aafa85911076":[2,0,0,1,20,61],
+"classSteinberg_1_1Vst_1_1HostCheckerController.html#a182625d2b02683f36ec4aafa85911076":[2,0,0,1,20,62],
 "classSteinberg_1_1Vst_1_1HostCheckerController.html#a1c5464feacdf2adcd6798bd672cc7414":[2,0,0,1,20,46],
-"classSteinberg_1_1Vst_1_1HostCheckerController.html#a2028ab458d2d798ff29b76a561306dc4":[2,0,0,1,20,62],
+"classSteinberg_1_1Vst_1_1HostCheckerController.html#a2028ab458d2d798ff29b76a561306dc4":[2,0,0,1,20,63],
 "classSteinberg_1_1Vst_1_1HostCheckerController.html#a272e5d4c8e24f012573f9f5b11f7f569":[2,0,0,1,20,11],
-"classSteinberg_1_1Vst_1_1HostCheckerController.html#a2994126983f1437424bafc780fa5919b":[2,0,0,1,20,53],
+"classSteinberg_1_1Vst_1_1HostCheckerController.html#a2994126983f1437424bafc780fa5919b":[2,0,0,1,20,54],
 "classSteinberg_1_1Vst_1_1HostCheckerController.html#a2acf420e46d11239fb9fb6f11447c41e":[2,0,0,1,20,5],
 "classSteinberg_1_1Vst_1_1HostCheckerController.html#a375821f541e8b3338d3e2dbfae7433d8":[2,0,0,1,20,14],
 "classSteinberg_1_1Vst_1_1HostCheckerController.html#a3ae1f7465f6641b01f76a098d0467b72":[2,0,0,1,20,15],
-"classSteinberg_1_1Vst_1_1HostCheckerController.html#a3ca86a9534ad2bb3adb4f5e4d71d68a5":[2,0,0,1,20,49],
+"classSteinberg_1_1Vst_1_1HostCheckerController.html#a3ca86a9534ad2bb3adb4f5e4d71d68a5":[2,0,0,1,20,50],
 "classSteinberg_1_1Vst_1_1HostCheckerController.html#a44748e8541aeedc907128769c8bfd023":[2,0,0,1,20,43],
 "classSteinberg_1_1Vst_1_1HostCheckerController.html#a480ad57ca0f00afd09fb0bb580865688":[2,0,0,1,20,42],
 "classSteinberg_1_1Vst_1_1HostCheckerController.html#a487e1f5b80a28b511301f98dca4a5d0b":[2,0,0,1,20,34],
@@ -76,52 +74,53 @@ var NAVTREEINDEX1 =
 "classSteinberg_1_1Vst_1_1HostCheckerController.html#a60bbab8211ead54d50dbb672be410342":[2,0,0,1,20,20],
 "classSteinberg_1_1Vst_1_1HostCheckerController.html#a65358ccb23d2c1b1ebc2e245eec0b824":[2,0,0,1,20,9],
 "classSteinberg_1_1Vst_1_1HostCheckerController.html#a668ebd0a20787d498f761c94e34f6203":[2,0,0,1,20,22],
-"classSteinberg_1_1Vst_1_1HostCheckerController.html#a67e68448677c53ae9cb4511ffd08672f":[2,0,0,1,20,67],
+"classSteinberg_1_1Vst_1_1HostCheckerController.html#a67e68448677c53ae9cb4511ffd08672f":[2,0,0,1,20,68],
 "classSteinberg_1_1Vst_1_1HostCheckerController.html#a7616efb48a8996352f9aefdd5d125924":[2,0,0,1,20,8],
 "classSteinberg_1_1Vst_1_1HostCheckerController.html#a77ade9b8fc6f6bd01f8c225dda17a415":[2,0,0,1,20,30],
-"classSteinberg_1_1Vst_1_1HostCheckerController.html#a7bd9dc65a3c41f9493abc417fa3342b1":[2,0,0,1,20,73],
+"classSteinberg_1_1Vst_1_1HostCheckerController.html#a7bd9dc65a3c41f9493abc417fa3342b1":[2,0,0,1,20,74],
 "classSteinberg_1_1Vst_1_1HostCheckerController.html#a7eb7bc3ca514ede042c8ad5d01414f4f":[2,0,0,1,20,6],
-"classSteinberg_1_1Vst_1_1HostCheckerController.html#a7f1abbcdbf4f1b3df814931a9579539d":[2,0,0,1,20,69],
+"classSteinberg_1_1Vst_1_1HostCheckerController.html#a7f1abbcdbf4f1b3df814931a9579539d":[2,0,0,1,20,70],
 "classSteinberg_1_1Vst_1_1HostCheckerController.html#a7fd8b0bb033a680562d59922175ae088":[2,0,0,1,20,7],
-"classSteinberg_1_1Vst_1_1HostCheckerController.html#a86f4dd968f780bf65369830c86adfa6a":[2,0,0,1,20,57],
-"classSteinberg_1_1Vst_1_1HostCheckerController.html#a893fe346bfbb357724bb3e4154ff80af":[2,0,0,1,20,48],
+"classSteinberg_1_1Vst_1_1HostCheckerController.html#a86f4dd968f780bf65369830c86adfa6a":[2,0,0,1,20,58],
+"classSteinberg_1_1Vst_1_1HostCheckerController.html#a893fe346bfbb357724bb3e4154ff80af":[2,0,0,1,20,49],
 "classSteinberg_1_1Vst_1_1HostCheckerController.html#a916c9d3245f4580b4effa6d977a64208":[2,0,0,1,20,13],
 "classSteinberg_1_1Vst_1_1HostCheckerController.html#a9228db732b48ece8b5b734e69b979d10":[2,0,0,1,20,27],
-"classSteinberg_1_1Vst_1_1HostCheckerController.html#a922bafd2d3b293f3718199dc804de0fe":[2,0,0,1,20,56],
+"classSteinberg_1_1Vst_1_1HostCheckerController.html#a922bafd2d3b293f3718199dc804de0fe":[2,0,0,1,20,57],
 "classSteinberg_1_1Vst_1_1HostCheckerController.html#a990e31f5d0bcc88d2c3a8e8c370a23ca":[2,0,0,1,20,25],
 "classSteinberg_1_1Vst_1_1HostCheckerController.html#a9c53db76959c3f687ebf0a9e039b5523":[2,0,0,1,20,24],
 "classSteinberg_1_1Vst_1_1HostCheckerController.html#a9cbc65f1d6c6bb0370a2cab22fda1d14":[2,0,0,1,20,45],
 "classSteinberg_1_1Vst_1_1HostCheckerController.html#a9d48aa02feb98d52c054d5f4198fa7c9":[2,0,0,1,20,12],
-"classSteinberg_1_1Vst_1_1HostCheckerController.html#a9ddae86018522bf2d708066884d89b3c":[2,0,0,1,20,64],
-"classSteinberg_1_1Vst_1_1HostCheckerController.html#a9eab817373e53002e792dfa711ba80ca":[2,0,0,1,20,54],
+"classSteinberg_1_1Vst_1_1HostCheckerController.html#a9ddae86018522bf2d708066884d89b3c":[2,0,0,1,20,65],
+"classSteinberg_1_1Vst_1_1HostCheckerController.html#a9eab817373e53002e792dfa711ba80ca":[2,0,0,1,20,55],
 "classSteinberg_1_1Vst_1_1HostCheckerController.html#aa2fea25360b1f4824345acc423b1f8db":[2,0,0,1,20,19],
-"classSteinberg_1_1Vst_1_1HostCheckerController.html#aa306b40e142d5ff3b73da7931b116690":[2,0,0,1,20,71],
+"classSteinberg_1_1Vst_1_1HostCheckerController.html#aa306b40e142d5ff3b73da7931b116690":[2,0,0,1,20,72],
 "classSteinberg_1_1Vst_1_1HostCheckerController.html#aa946c9736e3aad934fd2d9b7b916cc43":[2,0,0,1,20,3],
 "classSteinberg_1_1Vst_1_1HostCheckerController.html#ab3ab4a69e656ba2673a228fb6e22e2bd":[2,0,0,1,20,23],
-"classSteinberg_1_1Vst_1_1HostCheckerController.html#abaafe2485a80cde3e71a231286208fdb":[2,0,0,1,20,66],
+"classSteinberg_1_1Vst_1_1HostCheckerController.html#abaafe2485a80cde3e71a231286208fdb":[2,0,0,1,20,67],
 "classSteinberg_1_1Vst_1_1HostCheckerController.html#abc366969b6b2e1cef34c221db92e806d":[2,0,0,1,20,35],
-"classSteinberg_1_1Vst_1_1HostCheckerController.html#abcb2607c54f1115af6663eed8d3cee25":[2,0,0,1,20,59],
-"classSteinberg_1_1Vst_1_1HostCheckerController.html#ac01c6fa61e7f27fc13e2a7c47c27f792":[2,0,0,1,20,72],
-"classSteinberg_1_1Vst_1_1HostCheckerController.html#ac055deeb5f5ddca6e9e030e06a2fac7c":[2,0,0,1,20,47],
-"classSteinberg_1_1Vst_1_1HostCheckerController.html#ac24758feb9e31f29d8ca5505bfac794e":[2,0,0,1,20,52],
+"classSteinberg_1_1Vst_1_1HostCheckerController.html#abcb2607c54f1115af6663eed8d3cee25":[2,0,0,1,20,60],
+"classSteinberg_1_1Vst_1_1HostCheckerController.html#ac01c6fa61e7f27fc13e2a7c47c27f792":[2,0,0,1,20,73],
+"classSteinberg_1_1Vst_1_1HostCheckerController.html#ac055deeb5f5ddca6e9e030e06a2fac7c":[2,0,0,1,20,48],
+"classSteinberg_1_1Vst_1_1HostCheckerController.html#ac24758feb9e31f29d8ca5505bfac794e":[2,0,0,1,20,53],
 "classSteinberg_1_1Vst_1_1HostCheckerController.html#acbe6bf21938011dad882eda62cfde163":[2,0,0,1,20,39],
 "classSteinberg_1_1Vst_1_1HostCheckerController.html#accb2b76127645a7a8ec171c7b220ce8d":[2,0,0,1,20,31],
-"classSteinberg_1_1Vst_1_1HostCheckerController.html#ace6060dd0ae226a8628785a44198e4b8":[2,0,0,1,20,74],
-"classSteinberg_1_1Vst_1_1HostCheckerController.html#ad6796376ef5cc027ed35c4b2dd170f41":[2,0,0,1,20,65],
+"classSteinberg_1_1Vst_1_1HostCheckerController.html#ace6060dd0ae226a8628785a44198e4b8":[2,0,0,1,20,75],
+"classSteinberg_1_1Vst_1_1HostCheckerController.html#ad6796376ef5cc027ed35c4b2dd170f41":[2,0,0,1,20,66],
 "classSteinberg_1_1Vst_1_1HostCheckerController.html#ad8535466d93aa534a40ae1244940cc52":[2,0,0,1,20,32],
 "classSteinberg_1_1Vst_1_1HostCheckerController.html#ae5ece0a3a8c6e4295d9adedb76d6edd8":[2,0,0,1,20,4],
 "classSteinberg_1_1Vst_1_1HostCheckerController.html#aeb78d794ce0bc5812c526a1cc2083d5d":[2,0,0,1,20,16],
-"classSteinberg_1_1Vst_1_1HostCheckerController.html#aedf0d687c00670ca351bd00b0b83f440":[2,0,0,1,20,55],
-"classSteinberg_1_1Vst_1_1HostCheckerController.html#aedf35e1b48a24686ea03fbd738a9fc7c":[2,0,0,1,20,70],
+"classSteinberg_1_1Vst_1_1HostCheckerController.html#aedf0d687c00670ca351bd00b0b83f440":[2,0,0,1,20,56],
+"classSteinberg_1_1Vst_1_1HostCheckerController.html#aedf35e1b48a24686ea03fbd738a9fc7c":[2,0,0,1,20,71],
 "classSteinberg_1_1Vst_1_1HostCheckerController.html#aee393393dc4dccf6e0b30a43380859b4":[2,0,0,1,20,28],
-"classSteinberg_1_1Vst_1_1HostCheckerController.html#af161b55b382c62c4868a760fff750cd0":[2,0,0,1,20,50],
-"classSteinberg_1_1Vst_1_1HostCheckerController.html#af2233bd23acc913cd10e4a30916e5dda":[2,0,0,1,20,51],
+"classSteinberg_1_1Vst_1_1HostCheckerController.html#af161b55b382c62c4868a760fff750cd0":[2,0,0,1,20,51],
+"classSteinberg_1_1Vst_1_1HostCheckerController.html#af17f8cef5e2eac26dd4a327b20cb4da6":[2,0,0,1,20,47],
+"classSteinberg_1_1Vst_1_1HostCheckerController.html#af2233bd23acc913cd10e4a30916e5dda":[2,0,0,1,20,52],
 "classSteinberg_1_1Vst_1_1HostCheckerController.html#af4d16dae99ff1010b80359cb70500e31":[2,0,0,1,20,36],
 "classSteinberg_1_1Vst_1_1HostCheckerController.html#af63358114b145c306987ac513b4e908d":[2,0,0,1,20,2],
-"classSteinberg_1_1Vst_1_1HostCheckerController.html#af7bb4bec2475d18c304cc1263092e2cc":[2,0,0,1,20,68],
+"classSteinberg_1_1Vst_1_1HostCheckerController.html#af7bb4bec2475d18c304cc1263092e2cc":[2,0,0,1,20,69],
 "classSteinberg_1_1Vst_1_1HostCheckerController.html#af7e79066204c7e0be05f30d63bcafb24":[2,0,0,1,20,1],
 "classSteinberg_1_1Vst_1_1HostCheckerController.html#af90af6cdca41f0ab7ac5d4387c28efd8":[2,0,0,1,20,41],
-"classSteinberg_1_1Vst_1_1HostCheckerController.html#afc56b230d780947eb7b477efb0e055f0":[2,0,0,1,20,58],
+"classSteinberg_1_1Vst_1_1HostCheckerController.html#afc56b230d780947eb7b477efb0e055f0":[2,0,0,1,20,59],
 "classSteinberg_1_1Vst_1_1HostCheckerController.html#aff61c36b9f383b24e53096d1ff4ca451":[2,0,0,1,20,26],
 "classSteinberg_1_1Vst_1_1HostCheckerProcessor.html":[2,0,0,1,21],
 "classSteinberg_1_1Vst_1_1HostCheckerProcessor.html#a068f99a30130361e5520332a2352269d":[2,0,0,1,21,44],
@@ -249,5 +248,6 @@ var NAVTREEINDEX1 =
 "classSteinberg_1_1Vst_1_1NoteExpressionSynth_1_1Controller.html#a5d93e889ab504c7e08356683094be8a5":[2,0,0,1,2,2,6],
 "classSteinberg_1_1Vst_1_1NoteExpressionSynth_1_1Controller.html#a9d48aa02feb98d52c054d5f4198fa7c9":[2,0,0,1,2,2,3],
 "classSteinberg_1_1Vst_1_1NoteExpressionSynth_1_1Controller.html#aaad58ca2f563a040d5bbee68f033971d":[2,0,0,1,2,2,11],
-"classSteinberg_1_1Vst_1_1NoteExpressionSynth_1_1Controller.html#abc366969b6b2e1cef34c221db92e806d":[2,0,0,1,2,2,8]
+"classSteinberg_1_1Vst_1_1NoteExpressionSynth_1_1Controller.html#abc366969b6b2e1cef34c221db92e806d":[2,0,0,1,2,2,8],
+"classSteinberg_1_1Vst_1_1NoteExpressionSynth_1_1Controller.html#accb2b76127645a7a8ec171c7b220ce8d":[2,0,0,1,2,2,5]
 };
