@@ -9,9 +9,9 @@ var searchData=
   ['ucolorspec_2eh',['ucolorspec.h',['../../base/ucolorspec_8h.html',1,'']]],
   ['uiattributes',['UIAttributes',['../classSteinberg_1_1Vst_1_1PlugController.html#aa23cb9914ed88b85abf50aae448f7391',1,'Steinberg::Vst::PlugController']]],
   ['uibackgroundtask',['UIBackgroundTask',['../../vstinterfaces/classSteinberg_1_1Vst_1_1IProgress.html#a69d16526a64609e721e3a65f3353d666a8d3931cf6d187855412e0c5008bc945b',1,'Steinberg::Vst::IProgress::UIBackgroundTask()'],['../../vstinterfaces/classSteinberg_1_1Vst_1_1IProgress.html#a69d16526a64609e721e3a65f3353d666a8d3931cf6d187855412e0c5008bc945b',1,'Steinberg::Vst::IProgress::UIBackgroundTask()']]],
-  ['uid',['UID',['../../base/structSteinberg_1_1FUnknownImpl_1_1UID.html',1,'Steinberg::FUnknownImpl']]],
-  ['uid',['uid',['../../vstsdk/structVST3_1_1Hosting_1_1Module_1_1Snapshot.html#a99613136a67953261099533d962f9ac4',1,'VST3::Hosting::Module::Snapshot::uid()'],['../../base/structSteinberg_1_1FUnknownImpl_1_1UID.html#abbc1f7733b828c49be96e8e9aeb3fe2d',1,'Steinberg::FUnknownImpl::UID::UID()'],['../../vstsdk/structVST3_1_1UID.html#a3f5382d4c43a349d20eeff85a08d42b9',1,'VST3::UID::UID() noexcept=default'],['../../vstsdk/structVST3_1_1UID.html#a01a8fca87886bc6721818c064169732a',1,'VST3::UID::UID(uint32_t l1, uint32_t l2, uint32_t l3, uint32_t l4, bool comFormat=defaultComFormat) noexcept'],['../../vstsdk/structVST3_1_1UID.html#a3c51e756b20c74eaac5682a217fa7ec8',1,'VST3::UID::UID(const TUID &amp;uid) noexcept'],['../../vstsdk/structVST3_1_1UID.html#a504e965470eb308a23b2ee808e3a7f40',1,'VST3::UID::UID(const UID &amp;uid) noexcept']]],
   ['uid',['UID',['../../vstsdk/structVST3_1_1UID.html',1,'VST3']]],
+  ['uid',['UID',['../../base/structSteinberg_1_1FUnknownImpl_1_1UID.html#abbc1f7733b828c49be96e8e9aeb3fe2d',1,'Steinberg::FUnknownImpl::UID::UID()'],['../../vstsdk/structVST3_1_1UID.html#a3f5382d4c43a349d20eeff85a08d42b9',1,'VST3::UID::UID() noexcept=default'],['../../vstsdk/structVST3_1_1UID.html#a01a8fca87886bc6721818c064169732a',1,'VST3::UID::UID(uint32_t l1, uint32_t l2, uint32_t l3, uint32_t l4, bool comFormat=defaultComFormat) noexcept'],['../../vstsdk/structVST3_1_1UID.html#a3c51e756b20c74eaac5682a217fa7ec8',1,'VST3::UID::UID(const TUID &amp;uid) noexcept'],['../../vstsdk/structVST3_1_1UID.html#a504e965470eb308a23b2ee808e3a7f40',1,'VST3::UID::UID(const UID &amp;uid) noexcept'],['../../vstsdk/structVST3_1_1Hosting_1_1Module_1_1Snapshot.html#a99613136a67953261099533d962f9ac4',1,'VST3::Hosting::Module::Snapshot::uid()']]],
+  ['uid',['UID',['../../base/structSteinberg_1_1FUnknownImpl_1_1UID.html',1,'Steinberg::FUnknownImpl']]],
   ['uid_2eh',['uid.h',['../../vstsdk/uid_8h.html',1,'']]],
   ['uidprintstyle',['UIDPrintStyle',['../../base/classSteinberg_1_1FUID.html#a4c6d5af58eee71460b173f2a3fc16e83',1,'Steinberg::FUID']]],
   ['uimessagecontroller',['UIMessageController',['../classSteinberg_1_1Vst_1_1AGainController.html#ae6481b2aec7c49ca0673c645a305696a',1,'Steinberg::Vst::AGainController']]],
