@@ -16,7 +16,9 @@ var searchData=
   ['_7ecomponentbase',['~ComponentBase',['../../vstsdk/classSteinberg_1_1Vst_1_1ComponentBase.html#a992af1025ac7720ce29a87d926531e05',1,'Steinberg::Vst::AudioEffect']]],
   ['_7econnectionproxy',['~ConnectionProxy',['../../vstsdk/classSteinberg_1_1Vst_1_1ConnectionProxy.html#a891d1d252d711b7980defaba5112544f',1,'Steinberg::Vst::ConnectionProxy']]],
   ['_7econststringtable',['~ConstStringTable',['../../base/classSteinberg_1_1ConstStringTable.html#a99f647d997cd61d511fdf60560c5706b',1,'Steinberg::ConstStringTable']]],
-  ['_7ecpluginview',['~CPluginView',['../../vstsdk/classSteinberg_1_1CPluginView.html#a7f3eff5b630d169f894c01bdb2faf56d',1,'Steinberg::CPluginView']]],
+  ['_7ecpluginview',['~CPluginView',['../../vstsdk/classSteinberg_1_1CPluginView.html#a9242a8037a9e2355d4db0b4644e498ca',1,'Steinberg::CPluginView']]],
+  ['_7edataexchangehandler',['~DataExchangeHandler',['../../vstsdk/classSteinberg_1_1Vst_1_1DataExchangeHandler.html#a1198f6e88e7ba2ba5965aa4f0a592d72',1,'Steinberg::Vst::DataExchangeHandler']]],
+  ['_7edataexchangereceiverhandler',['~DataExchangeReceiverHandler',['../../vstsdk/classSteinberg_1_1Vst_1_1DataExchangeReceiverHandler.html#a1f2bdf21855cf544c941e22557450a58',1,'Steinberg::Vst::DataExchangeReceiverHandler']]],
   ['_7edeessercontroller',['~DeEsserController',['../classSteinberg_1_1Vst_1_1mda_1_1DeEsserController.html#aa508bb2127050ccb3cba6ba84dc09b91',1,'Steinberg::Vst::mda::DeEsserController']]],
   ['_7edeesserprocessor',['~DeEsserProcessor',['../classSteinberg_1_1Vst_1_1mda_1_1DeEsserProcessor.html#afb5bf7b43a8c473b293c43d0d8d6dcd2',1,'Steinberg::Vst::mda::DeEsserProcessor']]],
   ['_7edegradecontroller',['~DegradeController',['../classSteinberg_1_1Vst_1_1mda_1_1DegradeController.html#ad30ebb8444693ace8bcc07fe5161314f',1,'Steinberg::Vst::mda::DegradeController']]],
@@ -47,8 +49,10 @@ var searchData=
   ['_7efvariant',['~FVariant',['../../base/classSteinberg_1_1FVariant.html#ac4f5a08fe96561b601a95584bbf05632',1,'Steinberg::FVariant']]],
   ['_7ehostapplication',['~HostApplication',['../../vstsdk/classSteinberg_1_1Vst_1_1HostApplication.html#a682147e83d7a2350ed741b45f0e019cf',1,'Steinberg::Vst::HostApplication']]],
   ['_7ehostattributelist',['~HostAttributeList',['../../vstsdk/exceptionSteinberg_1_1Vst_1_1HostAttributeList.html#aaf902b05ae06e0ba573bf390edc0807c',1,'Steinberg::Vst::HostAttributeList']]],
+  ['_7ehostdataexchangehandler',['~HostDataExchangeHandler',['../../vstsdk/structSteinberg_1_1Vst_1_1HostDataExchangeHandler.html#ac44122529f3f8fc39b5f50431cd45926',1,'Steinberg::Vst::HostDataExchangeHandler']]],
   ['_7ehostmessage',['~HostMessage',['../../vstsdk/exceptionSteinberg_1_1Vst_1_1HostMessage.html#afa5e6400ac20881481fc810e945868fe',1,'Steinberg::Vst::HostMessage']]],
   ['_7ehostprocessdata',['~HostProcessData',['../../vstsdk/classSteinberg_1_1Vst_1_1HostProcessData.html#a99c0b5d3887e3704a467073443527e36',1,'Steinberg::Vst::HostProcessData']]],
+  ['_7eidataexchangehandlerhost',['~IDataExchangeHandlerHost',['../../vstsdk/structSteinberg_1_1Vst_1_1IDataExchangeHandlerHost.html#acd4bc3ac279ba44a9abd98934515f33b',1,'Steinberg::Vst::IDataExchangeHandlerHost']]],
   ['_7eimagecontroller',['~ImageController',['../classSteinberg_1_1Vst_1_1mda_1_1ImageController.html#abb7018df0560c1ce3c3485dc782e8b55',1,'Steinberg::Vst::mda::ImageController']]],
   ['_7eimageprocessor',['~ImageProcessor',['../classSteinberg_1_1Vst_1_1mda_1_1ImageProcessor.html#ad9c8c08393e8422518560215c3769216',1,'Steinberg::Vst::mda::ImageProcessor']]],
   ['_7eindexedparameter',['~IndexedParameter',['../classSteinberg_1_1Vst_1_1mda_1_1IndexedParameter.html#a74963ad2f899909051efd21b14d7280a',1,'Steinberg::Vst::mda::IndexedParameter']]],
