@@ -3,5 +3,6 @@ var modules =
     [ "Animation", "group__animation.html", "group__animation" ],
     [ "New classes", "group__new__in.html", "group__new__in" ],
     [ "Standalone Library", "group__standalone.html", "group__standalone" ],
-    [ "Views", "group__views.html", "group__views" ]
+    [ "Views", "group__views.html", "group__views" ],
+    [ "Views using Multi-Frame Bitmaps", "group__uses__multi__frame__bitmaps.html", "group__uses__multi__frame__bitmaps" ]
 ];
\ No newline at end of file
