@@ -59,7 +59,7 @@ var searchData=
   ['modifier',['modifier',['../struct_vst_key_code.html#ae3f31c0d691c7a842dbddc35afe1e4e5',1,'VstKeyCode']]],
   ['modifierevent',['ModifierEvent',['../struct_v_s_t_g_u_i_1_1_modifier_event.html',1,'VSTGUI']]],
   ['modifierkey',['ModifierKey',['../group__new__in__4__11.html#ga51910458d0a923b29f1694654d8eb00a',1,'VSTGUI']]],
-  ['modifiers',['modifiers',['../struct_v_s_t_g_u_i_1_1_drag_event_data.html#a42b465b57abcbac7a73dcc8cd147baed',1,'VSTGUI::DragEventData::modifiers()'],['../struct_v_s_t_g_u_i_1_1_modifier_event.html#a42b465b57abcbac7a73dcc8cd147baed',1,'VSTGUI::ModifierEvent::modifiers()'],['../struct_v_s_t_g_u_i_1_1_modifiers.html#adab327000fe96e2aa8772b581ecd8a57',1,'VSTGUI::Modifiers::Modifiers()=default'],['../struct_v_s_t_g_u_i_1_1_modifiers.html#a97ce8aae819d2797ac59fa8277ebf72d',1,'VSTGUI::Modifiers::Modifiers(const Modifiers &amp;)=default'],['../struct_v_s_t_g_u_i_1_1_modifiers.html#a97ae27d33dd8139211e4afb99cc39b0f',1,'VSTGUI::Modifiers::Modifiers(ModifierKey modifier)']]],
+  ['modifiers',['Modifiers',['../struct_v_s_t_g_u_i_1_1_modifiers.html#adab327000fe96e2aa8772b581ecd8a57',1,'VSTGUI::Modifiers::Modifiers()=default'],['../struct_v_s_t_g_u_i_1_1_modifiers.html#a97ce8aae819d2797ac59fa8277ebf72d',1,'VSTGUI::Modifiers::Modifiers(const Modifiers &amp;)=default'],['../struct_v_s_t_g_u_i_1_1_modifiers.html#a97ae27d33dd8139211e4afb99cc39b0f',1,'VSTGUI::Modifiers::Modifiers(ModifierKey modifier)'],['../struct_v_s_t_g_u_i_1_1_drag_event_data.html#a42b465b57abcbac7a73dcc8cd147baed',1,'VSTGUI::DragEventData::modifiers()'],['../struct_v_s_t_g_u_i_1_1_modifier_event.html#a42b465b57abcbac7a73dcc8cd147baed',1,'VSTGUI::ModifierEvent::modifiers()']]],
   ['modifiers',['Modifiers',['../struct_v_s_t_g_u_i_1_1_modifiers.html',1,'VSTGUI']]],
   ['mousebutton',['MouseButton',['../group__new__in__4__11.html#gab8d93bdfbb0fd7ae143bbfda46bf38bc',1,'VSTGUI']]],
   ['mousecancelevent',['MouseCancelEvent',['../struct_v_s_t_g_u_i_1_1_mouse_cancel_event.html',1,'VSTGUI']]],
