@@ -2,15 +2,20 @@ var group__plugType =
 [
     [ "kFx", "group__plugType.html#ga81395ffc74210c6b129ac5c1ad0f0450", null ],
     [ "kFxAnalyzer", "group__plugType.html#ga0017ff4ab459880956723e09c847188a", null ],
+    [ "kFxBass", "group__plugType.html#ga27b925ffb4f7d3da798f2b446fe06538", null ],
+    [ "kFxChannelStrip", "group__plugType.html#ga5a54a33f151d3d0068d43d377fbacaea", null ],
     [ "kFxDelay", "group__plugType.html#ga377e6c632bbed63329ad118e1d1f6780", null ],
     [ "kFxDistortion", "group__plugType.html#gad8da16bef223355cc58d3b469f876b33", null ],
+    [ "kFxDrums", "group__plugType.html#ga7cc4c653b53d167ebf833dc4bcd373ba", null ],
     [ "kFxDynamics", "group__plugType.html#ga9584914ab8362461d1bb4bac52ab9fd9", null ],
     [ "kFxEQ", "group__plugType.html#ga9dbf945372efb065d5f47af0aed0c498", null ],
     [ "kFxFilter", "group__plugType.html#gaf145d8e7f4ba5cf0b6f8d1373647451f", null ],
     [ "kFxGenerator", "group__plugType.html#gafe3ff646d102a4209512d6cda3b62ac4", null ],
+    [ "kFxGuitar", "group__plugType.html#ga5d7f914faef6c2a37eea292a7b16c76f", null ],
     [ "kFxInstrument", "group__plugType.html#gad632f4944a960678d6ff9b3886c878db", null ],
     [ "kFxInstrumentExternal", "group__plugType.html#ga0280f4b9390e12bf4b4846515572694a", null ],
     [ "kFxMastering", "group__plugType.html#ga6e00e778267b163458d145a6b6ac37b1", null ],
+    [ "kFxMicrophone", "group__plugType.html#gada3df3cb9ee2283e1dbae231d9d18644", null ],
     [ "kFxModulation", "group__plugType.html#ga2aea8d0a0d5d5e40680ce5260f52dafd", null ],
     [ "kFxNetwork", "group__plugType.html#gab2264c85ad07f983f365ca1c53489fe3", null ],
     [ "kFxPitchShift", "group__plugType.html#ga0759e804603c37125d02cbc3b091f03b", null ],
