@@ -76,9 +76,12 @@ var group__speakerArrangements =
     [ "kSpeakerBrl", "group__speakerArrangements.html#ga7932bc1e145b3d3c9d2d8b771dfe7626", null ],
     [ "kSpeakerBrc", "group__speakerArrangements.html#gaa8f469e8c1955c1aea25d0e6ad85b18e", null ],
     [ "kSpeakerBrr", "group__speakerArrangements.html#ga3818a39d5d27234b78a6dfa41385c749", null ],
+    [ "kSpeakerLw", "group__speakerArrangements.html#gaca69c24b92c7d38816ad871f662cb24d", null ],
+    [ "kSpeakerRw", "group__speakerArrangements.html#ga1b74afd94b2e5d860d1140c948b4dfff", null ],
     [ "kEmpty", "group__speakerArrangements.html#ga85ed4946e3abe83c91baa3e14d6a5e54", null ],
     [ "kMono", "group__speakerArrangements.html#ga571ff835d603ec5e98e54f1e0feca20e", null ],
     [ "kStereo", "group__speakerArrangements.html#ga9b5733786c71156513982991fa5f3c11", null ],
+    [ "kStereoWide", "group__speakerArrangements.html#ga17add6f7e226c7057f023d5fb79ea514", null ],
     [ "kStereoSurround", "group__speakerArrangements.html#gaad38856abd90805d1e85fe737677bbe8", null ],
     [ "kStereoCenter", "group__speakerArrangements.html#ga44710b9a538279e604b98213e8acdbec", null ],
     [ "kStereoSide", "group__speakerArrangements.html#ga98918bef7ba906d9b970ba49fb02a742", null ],
@@ -161,6 +164,10 @@ var group__speakerArrangements =
     [ "k91_4", "group__speakerArrangements.html#ga4f9e89d3c8dbbb4dac1e2cb67633615b", null ],
     [ "k90_6", "group__speakerArrangements.html#ga88accb0a3074c3fb6eb3fdb490b21c62", null ],
     [ "k91_6", "group__speakerArrangements.html#gaaa5bdf5a10ab4f4930c1ecf4efeb3f95", null ],
+    [ "k90_4_W", "group__speakerArrangements.html#ga270ac2f122e02a0570bb5eff60e7f9d1", null ],
+    [ "k91_4_W", "group__speakerArrangements.html#gacd9798993a2e72b8ea9ec5d6f304bb35", null ],
+    [ "k90_6_W", "group__speakerArrangements.html#ga3a48ceea90b000d970319d3c5370855b", null ],
+    [ "k91_6_W", "group__speakerArrangements.html#ga31c77ba2ccde7c76357149b9be8d1141", null ],
     [ "k100", "group__speakerArrangements.html#ga6cadcafb161f16aa7edcc676604e4def", null ],
     [ "k50_5", "group__speakerArrangements.html#ga07f09cbbdc4d96c628d69523a40d67ba", null ],
     [ "k101", "group__speakerArrangements.html#ga13c1699c11fba17352b83a1b3a7cfcc8", null ],
@@ -197,6 +204,7 @@ var group__speakerArrangements =
     [ "kStringEmpty", "group__speakerArrangements.html#ga38c557da6a4db5884d2d688c30cc5553", null ],
     [ "kStringMono", "group__speakerArrangements.html#gacc3c2f0d3a1a7cefebcd21afcaff0a33", null ],
     [ "kStringStereo", "group__speakerArrangements.html#gaa8801dd84fb2f8566448a99c418d1185", null ],
+    [ "kStringStereoWide", "group__speakerArrangements.html#gac2c7b9174c8b38607b2cb2e68769aaca", null ],
     [ "kStringStereoR", "group__speakerArrangements.html#ga7baad18ef660784d5ed89c95d0f16aa9", null ],
     [ "kStringStereoC", "group__speakerArrangements.html#ga2057f29b65596edf1cb80ccc6a041b83", null ],
     [ "kStringStereoSide", "group__speakerArrangements.html#gabab50191c9f7c6a497f7d148cc3a9741", null ],
@@ -263,6 +271,10 @@ var group__speakerArrangements =
     [ "kString91_4", "group__speakerArrangements.html#ga3b0b6d1ed6af07daa84a016f9a594d59", null ],
     [ "kString90_6", "group__speakerArrangements.html#gaa1fe4d708fa32e7b1ddeb892fa073509", null ],
     [ "kString91_6", "group__speakerArrangements.html#gab8ec511d08a024efcfc54258ddaf48cf", null ],
+    [ "kString90_4_W", "group__speakerArrangements.html#gaabc2aa69822cda0da6dfd4b9f25b6cdb", null ],
+    [ "kString91_4_W", "group__speakerArrangements.html#ga906abecafe08c67b51a1b6f97d3f9202", null ],
+    [ "kString90_6_W", "group__speakerArrangements.html#ga88b22a1f32010aabb2d47d8f75211dbb", null ],
+    [ "kString91_6_W", "group__speakerArrangements.html#gabfd5019295ebd78f65cb5e1e39b47a82", null ],
     [ "kString50_5", "group__speakerArrangements.html#ga78e757a9d10fe70b7ee5a16ddd02cd1e", null ],
     [ "kString51_5", "group__speakerArrangements.html#ga6ad5cb522b313a38c2134c7706b73027", null ],
     [ "kString50_6", "group__speakerArrangements.html#gad826493413cb2611f94658e9ed2c2520", null ],
@@ -294,6 +306,7 @@ var group__speakerArrangements =
     [ "kStringAmbi7thOrder", "group__speakerArrangements.html#gaeae5f636bab30a1fc18cb36210b23b56", null ],
     [ "kStringMonoS", "group__speakerArrangements.html#ga646cd09e52190d60f2d4ca83faf915aa", null ],
     [ "kStringStereoS", "group__speakerArrangements.html#ga54144ab0e1dd2babcf5e720950cf7e24", null ],
+    [ "kStringStereoWideS", "group__speakerArrangements.html#ga3160617565b0ad36d34a025fe119bbb6", null ],
     [ "kStringStereoRS", "group__speakerArrangements.html#ga63f3673e0a9ad13c3788b583d4fac61b", null ],
     [ "kStringStereoCS", "group__speakerArrangements.html#ga3cb0fc4337ff0f43bf119b20c7f5d810", null ],
     [ "kStringStereoSS", "group__speakerArrangements.html#ga22b0cac49e8ef5b3d9a1836abd021720", null ],
@@ -354,6 +367,10 @@ var group__speakerArrangements =
     [ "kString91_4S", "group__speakerArrangements.html#ga1b17445201a92bee4c23dd16e5cd1728", null ],
     [ "kString90_6S", "group__speakerArrangements.html#gac89dcac8a9acb594a3e406cc5241d650", null ],
     [ "kString91_6S", "group__speakerArrangements.html#gaf0b16e15ff6616a3e481b879d3b4c53f", null ],
+    [ "kString90_4_WS", "group__speakerArrangements.html#gaea91261d917acadf9dd3de00dbc5161c", null ],
+    [ "kString91_4_WS", "group__speakerArrangements.html#ga791d374620b4a4c9181e66339a61bf91", null ],
+    [ "kString90_6_WS", "group__speakerArrangements.html#gac5315e218c209f891d18ec25effa0fd1", null ],
+    [ "kString91_6_WS", "group__speakerArrangements.html#ga19887804c5277a7d95cb691486752326", null ],
     [ "kString50_5S", "group__speakerArrangements.html#ga597dea323dcd6ebf7a8f79e222744396", null ],
     [ "kString51_5S", "group__speakerArrangements.html#ga693724048ed9aa6572030b22a0c722d5", null ],
     [ "kString50_5_SonyS", "group__speakerArrangements.html#ga7697d22e6e22fa8c6948bd482737ce62", null ],
