@@ -2,47 +2,49 @@ var NAVTREEINDEX1 =
 {
 "classSteinberg_1_1Vst_1_1IProgress.html#a7da93484ec5338cb5b7cfa586b2a4387":[2,0,0,1,38,0],
 "classSteinberg_1_1Vst_1_1IProgress.html#ac30d985ff73621fa4dd18c67b096e590":[2,0,0,1,38,2],
+"classSteinberg_1_1Vst_1_1IRemapParamID.html":[2,0,0,1,82],
+"classSteinberg_1_1Vst_1_1IRemapParamID.html#a8ccb7e4738dea0f31fad680fe7bdf860":[2,0,0,1,82,0],
 "classSteinberg_1_1Vst_1_1IStreamAttributes.html":[2,0,0,1,17],
 "classSteinberg_1_1Vst_1_1IStreamAttributes.html#a97646f7e4a63e3ba42454b35f80cd336":[2,0,0,1,17,1],
 "classSteinberg_1_1Vst_1_1IStreamAttributes.html#ad8d90e182b51e387734f307c2c12a2f4":[2,0,0,1,17,0],
-"classSteinberg_1_1Vst_1_1ITestPlugProvider.html":[2,0,0,1,84],
-"classSteinberg_1_1Vst_1_1ITestPlugProvider.html#a3684bfce1f1a4c1141765095613bb424":[2,0,0,1,84,3],
-"classSteinberg_1_1Vst_1_1ITestPlugProvider.html#a41ed5d90224e89e2eeaa8efba4e6de6e":[2,0,0,1,84,4],
-"classSteinberg_1_1Vst_1_1ITestPlugProvider.html#a56e195d1d9cb606f7a17c49b5efcc3c9":[2,0,0,1,84,2],
-"classSteinberg_1_1Vst_1_1ITestPlugProvider.html#aaf82c4f26b97f522e6ead97028a3f7c4":[2,0,0,1,84,1],
-"classSteinberg_1_1Vst_1_1ITestPlugProvider.html#abec872fb216eae440b5b7de078d464a6":[2,0,0,1,84,0],
-"classSteinberg_1_1Vst_1_1ITestPlugProvider2.html":[2,0,0,1,85],
-"classSteinberg_1_1Vst_1_1ITestPlugProvider2.html#a9dcc98679997d133da909913d65b66ef":[2,0,0,1,85,0],
-"classSteinberg_1_1Vst_1_1IUnitData.html":[2,0,0,1,92],
-"classSteinberg_1_1Vst_1_1IUnitData.html#a0ea283ed20afcc7f1b860abd05064bbb":[2,0,0,1,92,1],
-"classSteinberg_1_1Vst_1_1IUnitData.html#a77520fed67487e60b57cebde871d7f48":[2,0,0,1,92,0],
-"classSteinberg_1_1Vst_1_1IUnitData.html#aa01ffe25404ad1810e9076e205ce25fa":[2,0,0,1,92,2],
-"classSteinberg_1_1Vst_1_1IUnitHandler.html":[2,0,0,1,88],
-"classSteinberg_1_1Vst_1_1IUnitHandler.html#a3f4dc142ae3d50a04aa416fee14d4da4":[2,0,0,1,88,1],
-"classSteinberg_1_1Vst_1_1IUnitHandler.html#ab05a9a8dcca888caeabdb8ed74766bc6":[2,0,0,1,88,0],
-"classSteinberg_1_1Vst_1_1IUnitHandler2.html":[2,0,0,1,89],
-"classSteinberg_1_1Vst_1_1IUnitHandler2.html#ad1f48213839cc5b28a612a2baaba6584":[2,0,0,1,89,0],
-"classSteinberg_1_1Vst_1_1IUnitInfo.html":[2,0,0,1,90],
-"classSteinberg_1_1Vst_1_1IUnitInfo.html#a0db929591fd4fc242935edb91e65ed30":[2,0,0,1,90,3],
-"classSteinberg_1_1Vst_1_1IUnitInfo.html#a23fd4bc09e5bfee39c31bbba1ab2385b":[2,0,0,1,90,0],
-"classSteinberg_1_1Vst_1_1IUnitInfo.html#a2504c2bb3c57742102577f34cb58e257":[2,0,0,1,90,9],
-"classSteinberg_1_1Vst_1_1IUnitInfo.html#a2d04f6147a8c2d4b11e9cb9aae39514b":[2,0,0,1,90,2],
-"classSteinberg_1_1Vst_1_1IUnitInfo.html#a4417b27a9a3730bc49a933bc0d2bde7d":[2,0,0,1,90,4],
-"classSteinberg_1_1Vst_1_1IUnitInfo.html#a6126c4506f7981b5e800c6b4daa1e66b":[2,0,0,1,90,7],
-"classSteinberg_1_1Vst_1_1IUnitInfo.html#a63c02601259d4e8690f26eefaad53195":[2,0,0,1,90,6],
-"classSteinberg_1_1Vst_1_1IUnitInfo.html#a6f1b43425ba894764f35b7d492e81c53":[2,0,0,1,90,8],
-"classSteinberg_1_1Vst_1_1IUnitInfo.html#a718fa905d04d7d559bc89c7ca761413b":[2,0,0,1,90,10],
-"classSteinberg_1_1Vst_1_1IUnitInfo.html#a7cbc86917a614918938277be9bb52e6f":[2,0,0,1,90,11],
-"classSteinberg_1_1Vst_1_1IUnitInfo.html#ac40c799f1f52837c311ac153d7a8ead7":[2,0,0,1,90,5],
-"classSteinberg_1_1Vst_1_1IUnitInfo.html#ad32cdcda859f588c84e76133f2d62923":[2,0,0,1,90,1],
+"classSteinberg_1_1Vst_1_1ITestPlugProvider.html":[2,0,0,1,85],
+"classSteinberg_1_1Vst_1_1ITestPlugProvider.html#a3684bfce1f1a4c1141765095613bb424":[2,0,0,1,85,3],
+"classSteinberg_1_1Vst_1_1ITestPlugProvider.html#a41ed5d90224e89e2eeaa8efba4e6de6e":[2,0,0,1,85,4],
+"classSteinberg_1_1Vst_1_1ITestPlugProvider.html#a56e195d1d9cb606f7a17c49b5efcc3c9":[2,0,0,1,85,2],
+"classSteinberg_1_1Vst_1_1ITestPlugProvider.html#aaf82c4f26b97f522e6ead97028a3f7c4":[2,0,0,1,85,1],
+"classSteinberg_1_1Vst_1_1ITestPlugProvider.html#abec872fb216eae440b5b7de078d464a6":[2,0,0,1,85,0],
+"classSteinberg_1_1Vst_1_1ITestPlugProvider2.html":[2,0,0,1,86],
+"classSteinberg_1_1Vst_1_1ITestPlugProvider2.html#a9dcc98679997d133da909913d65b66ef":[2,0,0,1,86,0],
+"classSteinberg_1_1Vst_1_1IUnitData.html":[2,0,0,1,93],
+"classSteinberg_1_1Vst_1_1IUnitData.html#a0ea283ed20afcc7f1b860abd05064bbb":[2,0,0,1,93,1],
+"classSteinberg_1_1Vst_1_1IUnitData.html#a77520fed67487e60b57cebde871d7f48":[2,0,0,1,93,0],
+"classSteinberg_1_1Vst_1_1IUnitData.html#aa01ffe25404ad1810e9076e205ce25fa":[2,0,0,1,93,2],
+"classSteinberg_1_1Vst_1_1IUnitHandler.html":[2,0,0,1,89],
+"classSteinberg_1_1Vst_1_1IUnitHandler.html#a3f4dc142ae3d50a04aa416fee14d4da4":[2,0,0,1,89,1],
+"classSteinberg_1_1Vst_1_1IUnitHandler.html#ab05a9a8dcca888caeabdb8ed74766bc6":[2,0,0,1,89,0],
+"classSteinberg_1_1Vst_1_1IUnitHandler2.html":[2,0,0,1,90],
+"classSteinberg_1_1Vst_1_1IUnitHandler2.html#ad1f48213839cc5b28a612a2baaba6584":[2,0,0,1,90,0],
+"classSteinberg_1_1Vst_1_1IUnitInfo.html":[2,0,0,1,91],
+"classSteinberg_1_1Vst_1_1IUnitInfo.html#a0db929591fd4fc242935edb91e65ed30":[2,0,0,1,91,3],
+"classSteinberg_1_1Vst_1_1IUnitInfo.html#a23fd4bc09e5bfee39c31bbba1ab2385b":[2,0,0,1,91,0],
+"classSteinberg_1_1Vst_1_1IUnitInfo.html#a2504c2bb3c57742102577f34cb58e257":[2,0,0,1,91,9],
+"classSteinberg_1_1Vst_1_1IUnitInfo.html#a2d04f6147a8c2d4b11e9cb9aae39514b":[2,0,0,1,91,2],
+"classSteinberg_1_1Vst_1_1IUnitInfo.html#a4417b27a9a3730bc49a933bc0d2bde7d":[2,0,0,1,91,4],
+"classSteinberg_1_1Vst_1_1IUnitInfo.html#a6126c4506f7981b5e800c6b4daa1e66b":[2,0,0,1,91,7],
+"classSteinberg_1_1Vst_1_1IUnitInfo.html#a63c02601259d4e8690f26eefaad53195":[2,0,0,1,91,6],
+"classSteinberg_1_1Vst_1_1IUnitInfo.html#a6f1b43425ba894764f35b7d492e81c53":[2,0,0,1,91,8],
+"classSteinberg_1_1Vst_1_1IUnitInfo.html#a718fa905d04d7d559bc89c7ca761413b":[2,0,0,1,91,10],
+"classSteinberg_1_1Vst_1_1IUnitInfo.html#a7cbc86917a614918938277be9bb52e6f":[2,0,0,1,91,11],
+"classSteinberg_1_1Vst_1_1IUnitInfo.html#ac40c799f1f52837c311ac153d7a8ead7":[2,0,0,1,91,5],
+"classSteinberg_1_1Vst_1_1IUnitInfo.html#ad32cdcda859f588c84e76133f2d62923":[2,0,0,1,91,1],
 "classSteinberg_1_1Vst_1_1IVst3ToAAXWrapper.html":[2,0,0,1,56],
 "classSteinberg_1_1Vst_1_1IVst3ToAUWrapper.html":[2,0,0,1,55],
 "classSteinberg_1_1Vst_1_1IVst3ToVst2Wrapper.html":[2,0,0,1,54],
 "classSteinberg_1_1Vst_1_1IVst3WrapperMPESupport.html":[2,0,0,1,57],
 "classSteinberg_1_1Vst_1_1IVst3WrapperMPESupport.html#a322e79e7c76c3e2b5f717e9666870c58":[2,0,0,1,57,0],
 "classSteinberg_1_1Vst_1_1IVst3WrapperMPESupport.html#ae3cece9ab989e0769cb14377e2f719b1":[2,0,0,1,57,1],
-"classSteinberg_1_1Vst_1_1IXmlRepresentationController.html":[2,0,0,1,83],
-"classSteinberg_1_1Vst_1_1IXmlRepresentationController.html#a12aaff5f46c6f620fb724e9c9763ac21":[2,0,0,1,83,0],
+"classSteinberg_1_1Vst_1_1IXmlRepresentationController.html":[2,0,0,1,84],
+"classSteinberg_1_1Vst_1_1IXmlRepresentationController.html#a12aaff5f46c6f620fb724e9c9763ac21":[2,0,0,1,84,0],
 "classes.html":[2,1],
 "files.html":[3,0],
 "functions.html":[2,3,0],
@@ -247,7 +249,5 @@ var NAVTREEINDEX1 =
 "group__musicalInstrument.html#gac756e1798f6f8ce4eed78adafcd6f8b4":[0,5,32],
 "group__musicalInstrument.html#gacbe3eb6871b48061d2c046d8b258a7a9":[0,5,60],
 "group__musicalInstrument.html#gaccf4a6cc04deede6234aa80f17494e62":[0,5,9],
-"group__musicalInstrument.html#gad21b480ba2888b09f222c703fbb37a91":[0,5,71],
-"group__musicalInstrument.html#gad3c91ff5b7e51b5ed71479994af1f2b0":[0,5,104],
-"group__musicalInstrument.html#gadec30a0adbbd248d6573f64342feef77":[0,5,33]
+"group__musicalInstrument.html#gad21b480ba2888b09f222c703fbb37a91":[0,5,71]
 };
