@@ -11,6 +11,7 @@ var searchData=
   ['hasprogrampitchnames',['hasProgramPitchNames',['../../vstsdk/classSteinberg_1_1Vst_1_1EditControllerEx1.html#a803746c6ff155524e28fe85754483a23',1,'Steinberg::Vst::EditControllerEx1::hasProgramPitchNames()'],['../classSteinberg_1_1Vst_1_1IUnitInfo.html#a63c02601259d4e8690f26eefaad53195',1,'Steinberg::Vst::IUnitInfo::hasProgramPitchNames()']]],
   ['hastopspeakers',['hasTopSpeakers',['../group__speakerArrangements.html#ga2fd1d5b534428e6414e46829089313f9',1,'Steinberg::Vst::SpeakerArr']]],
   ['havepointsbeenread',['havePointsBeenRead',['../../vstsdk/classSteinberg_1_1Vst_1_1ParamChanges.html#ad9ef33d81be2e39cc162a3ac4f9a8983',1,'Steinberg::Vst::ParamChanges']]],
+  ['hideiidbase',['HideIIDBase',['../../base/structSteinberg_1_1FUnknownImpl_1_1HideIIDBase.html',1,'Steinberg::FUnknownImpl']]],
   ['host',['host',['../structSteinberg_1_1Vst_1_1RepresentationInfo.html#a74766a169cd1c18bc001b99e1984a901',1,'Steinberg::Vst::RepresentationInfo']]],
   ['hostapp_2eh',['HostApp.h',['../../vstsdk/HostApp_8h.html',1,'']]],
   ['hostapp_2emm',['HostApp.mm',['../../vstsdk/HostApp_8mm.html',1,'']]],
@@ -19,6 +20,10 @@ var searchData=
   ['hostattributelist',['HostAttributeList',['../../vstsdk/exceptionSteinberg_1_1Vst_1_1HostAttributeList.html',1,'Steinberg::Vst']]],
   ['hostclasses_2ecpp',['hostclasses.cpp',['../../vstsdk/hostclasses_8cpp.html',1,'']]],
   ['hostclasses_2eh',['hostclasses.h',['../../vstsdk/hostclasses_8h.html',1,'']]],
+  ['hostdataexchangehandler',['HostDataExchangeHandler',['../../vstsdk/structSteinberg_1_1Vst_1_1HostDataExchangeHandler.html#a72c00ee9d1c317e2075880659f34a399',1,'Steinberg::Vst::HostDataExchangeHandler']]],
+  ['hostdataexchangehandler',['HostDataExchangeHandler',['../../vstsdk/structSteinberg_1_1Vst_1_1HostDataExchangeHandler.html',1,'Steinberg::Vst']]],
+  ['hostdataexchangehandler_2ecpp',['hostdataexchangehandler.cpp',['../../vstsdk/hostdataexchangehandler_8cpp.html',1,'']]],
+  ['hostdataexchangehandler_2eh',['hostdataexchangehandler.h',['../../vstsdk/hostdataexchangehandler_8h.html',1,'']]],
   ['hostknobmode',['hostKnobMode',['../../vstsdk/classSteinberg_1_1Vst_1_1EditController.html#aec9109c6f108a19e1c9220fbe52cb903',1,'Steinberg::Vst::EditController']]],
   ['hostmessage',['HostMessage',['../../vstsdk/exceptionSteinberg_1_1Vst_1_1HostMessage.html#abe5688697369115f0e7e72c362258a75',1,'Steinberg::Vst::HostMessage']]],
   ['hostmessage',['HostMessage',['../../vstsdk/exceptionSteinberg_1_1Vst_1_1HostMessage.html',1,'Steinberg::Vst']]],
