@@ -105,7 +105,7 @@ var searchData=
   ['processcontext',['processContext',['../structSteinberg_1_1Vst_1_1ProcessData.html#ad27334aa1361d4ff3b139ca305bf1fad',1,'Steinberg::Vst::ProcessData']]],
   ['processcontext',['ProcessContext',['../structSteinberg_1_1Vst_1_1ProcessContext.html',1,'Steinberg::Vst']]],
   ['processcontextrequirements',['ProcessContextRequirements',['../../vstsdk/classSteinberg_1_1Vst_1_1ProcessContextRequirements.html',1,'Steinberg::Vst']]],
-  ['processcontextrequirements',['ProcessContextRequirements',['../../vstsdk/classSteinberg_1_1Vst_1_1ProcessContextRequirements.html#ae40c5b12ded747e7f7ab4d52bd7c8907',1,'Steinberg::Vst::ProcessContextRequirements::ProcessContextRequirements()'],['../../vstsdk/classSteinberg_1_1Vst_1_1AudioEffect.html#acf51f81f4a57d1be775b5dd4ad64734b',1,'Steinberg::Vst::AudioEffect::processContextRequirements()'],['../../vstsdk/classSteinberg_1_1Vst_1_1SingleComponentEffect.html#a2aaa8a8f65932a7e8157ef6a251ddd6f',1,'Steinberg::Vst::SingleComponentEffect::processContextRequirements()']]],
+  ['processcontextrequirements',['processContextRequirements',['../../vstsdk/classSteinberg_1_1Vst_1_1AudioEffect.html#acf51f81f4a57d1be775b5dd4ad64734b',1,'Steinberg::Vst::AudioEffect::processContextRequirements()'],['../../vstsdk/classSteinberg_1_1Vst_1_1SingleComponentEffect.html#a2aaa8a8f65932a7e8157ef6a251ddd6f',1,'Steinberg::Vst::SingleComponentEffect::processContextRequirements()'],['../../vstsdk/classSteinberg_1_1Vst_1_1ProcessContextRequirements.html#ae40c5b12ded747e7f7ab4d52bd7c8907',1,'Steinberg::Vst::ProcessContextRequirements::ProcessContextRequirements()']]],
   ['processcontextrequirements_2eh',['processcontextrequirements.h',['../../vstsdk/processcontextrequirements_8h.html',1,'']]],
   ['processdata',['ProcessData',['../structSteinberg_1_1Vst_1_1ProcessData.html#a100f97803b72565daedee80e34bbb7f0',1,'Steinberg::Vst::ProcessData']]],
   ['processdata',['ProcessData',['../structSteinberg_1_1Vst_1_1ProcessData.html',1,'Steinberg::Vst']]],
@@ -134,11 +134,11 @@ var searchData=
   ['programlistwithpitchnames',['ProgramListWithPitchNames',['../../vstsdk/classSteinberg_1_1Vst_1_1ProgramListWithPitchNames.html#ac35cdc8c766d4de4e9677d278c01382a',1,'Steinberg::Vst::ProgramListWithPitchNames']]],
   ['programlistwithpitchnames',['ProgramListWithPitchNames',['../../vstsdk/classSteinberg_1_1Vst_1_1ProgramListWithPitchNames.html',1,'Steinberg::Vst']]],
   ['programnames',['programNames',['../../vstsdk/classSteinberg_1_1Vst_1_1ProgramList.html#a374d0d28218114229c2469dec596b9ff',1,'Steinberg::Vst::ProgramList']]],
-  ['programs',['Programs',['../../vstsdk/structVST3_1_1Vst2xState.html#a6a250ebf1916f9297dbedc8fc488ddb4',1,'VST3::Vst2xState::Programs()'],['../../vstsdk/structVST3_1_1Vst2xState.html#a69649642bc65a780bbab905b1c57aba7',1,'VST3::Vst2xState::programs()']]],
+  ['programs',['programs',['../../vstsdk/structVST3_1_1Vst2xState.html#a69649642bc65a780bbab905b1c57aba7',1,'VST3::Vst2xState::programs()'],['../../vstsdk/structVST3_1_1Vst2xState.html#a6a250ebf1916f9297dbedc8fc488ddb4',1,'VST3::Vst2xState::Programs()']]],
   ['programvalues',['ProgramValues',['../../vstsdk/structVST3_1_1Vst2xProgram.html#a2bc036956ebdabf74742defb97bee043',1,'VST3::Vst2xProgram']]],
   ['progresstype',['ProgressType',['../classSteinberg_1_1Vst_1_1IProgress.html#a69d16526a64609e721e3a65f3353d666',1,'Steinberg::Vst::IProgress']]],
   ['projecttimemusic',['projectTimeMusic',['../structSteinberg_1_1Vst_1_1ProcessContext.html#a4c1e16437e0c0858fa5288107e5b187f',1,'Steinberg::Vst::ProcessContext']]],
   ['projecttimesamples',['projectTimeSamples',['../structSteinberg_1_1Vst_1_1ProcessContext.html#a359d649ae34734b9876ad5a6a2f691f7',1,'Steinberg::Vst::ProcessContext']]],
-  ['ptr',['ptr',['../../base/classSteinberg_1_1IPtr.html#a7c145f458643ff993b929f236d4a2ac0',1,'Steinberg::FUnknownPtr::ptr()'],['../../vstsdk/classVST3_1_1Hosting_1_1Module.html#a6b597424e1e3214bbaa370140e784b15',1,'VST3::Hosting::Module::Ptr()']]],
+  ['ptr',['Ptr',['../../vstsdk/classVST3_1_1Hosting_1_1Module.html#a6b597424e1e3214bbaa370140e784b15',1,'VST3::Hosting::Module::Ptr()'],['../../base/classSteinberg_1_1IPtr.html#a7c145f458643ff993b929f236d4a2ac0',1,'Steinberg::FUnknownPtr::ptr()']]],
   ['push',['push',['../../vstsdk/classSteinberg_1_1OneReaderOneWriter_1_1RingBuffer.html#abbabbc28c5f4f8830e2ed06b19ea9549',1,'Steinberg::OneReaderOneWriter::RingBuffer::push(ItemT &amp;&amp;item) noexcept'],['../../vstsdk/classSteinberg_1_1OneReaderOneWriter_1_1RingBuffer.html#a91f11a2997e9e08387ea391c50fc1e98',1,'Steinberg::OneReaderOneWriter::RingBuffer::push(const ItemT &amp;item) noexcept']]]
 ];
