@@ -3,9 +3,9 @@ var searchData=
   ['u',['u',['../../base/structSteinberg_1_1FReleaser.html#adcb624ac2e22762ff3ef4a83c423d84f',1,'Steinberg::FReleaser']]],
   ['ucolorspec_2eh',['ucolorspec.h',['../../base/ucolorspec_8h.html',1,'']]],
   ['uibackgroundtask',['UIBackgroundTask',['../classSteinberg_1_1Vst_1_1IProgress.html#a69d16526a64609e721e3a65f3353d666a8d3931cf6d187855412e0c5008bc945b',1,'Steinberg::Vst::IProgress']]],
-  ['uid',['UID',['../../vstsdk/structVST3_1_1UID.html',1,'VST3']]],
   ['uid',['UID',['../../base/structSteinberg_1_1FUnknownImpl_1_1UID.html',1,'Steinberg::FUnknownImpl']]],
-  ['uid',['uid',['../../vstsdk/structVST3_1_1Hosting_1_1Module_1_1Snapshot.html#a99613136a67953261099533d962f9ac4',1,'VST3::Hosting::Module::Snapshot::uid()'],['../../base/structSteinberg_1_1FUnknownImpl_1_1UID.html#abbc1f7733b828c49be96e8e9aeb3fe2d',1,'Steinberg::FUnknownImpl::UID::UID()'],['../../vstsdk/structVST3_1_1UID.html#a3f5382d4c43a349d20eeff85a08d42b9',1,'VST3::UID::UID() noexcept=default'],['../../vstsdk/structVST3_1_1UID.html#a01a8fca87886bc6721818c064169732a',1,'VST3::UID::UID(uint32_t l1, uint32_t l2, uint32_t l3, uint32_t l4, bool comFormat=defaultComFormat) noexcept'],['../../vstsdk/structVST3_1_1UID.html#a3c51e756b20c74eaac5682a217fa7ec8',1,'VST3::UID::UID(const TUID &amp;uid) noexcept'],['../../vstsdk/structVST3_1_1UID.html#a504e965470eb308a23b2ee808e3a7f40',1,'VST3::UID::UID(const UID &amp;uid) noexcept']]],
+  ['uid',['UID',['../../vstsdk/structVST3_1_1UID.html',1,'VST3']]],
+  ['uid',['UID',['../../base/structSteinberg_1_1FUnknownImpl_1_1UID.html#abbc1f7733b828c49be96e8e9aeb3fe2d',1,'Steinberg::FUnknownImpl::UID::UID()'],['../../vstsdk/structVST3_1_1UID.html#a3f5382d4c43a349d20eeff85a08d42b9',1,'VST3::UID::UID() noexcept=default'],['../../vstsdk/structVST3_1_1UID.html#a01a8fca87886bc6721818c064169732a',1,'VST3::UID::UID(uint32_t l1, uint32_t l2, uint32_t l3, uint32_t l4, bool comFormat=defaultComFormat) noexcept'],['../../vstsdk/structVST3_1_1UID.html#a3c51e756b20c74eaac5682a217fa7ec8',1,'VST3::UID::UID(const TUID &amp;uid) noexcept'],['../../vstsdk/structVST3_1_1UID.html#a504e965470eb308a23b2ee808e3a7f40',1,'VST3::UID::UID(const UID &amp;uid) noexcept'],['../../vstsdk/structVST3_1_1Hosting_1_1Module_1_1Snapshot.html#a99613136a67953261099533d962f9ac4',1,'VST3::Hosting::Module::Snapshot::uid()']]],
   ['uid_2eh',['uid.h',['../../vstsdk/uid_8h.html',1,'']]],
   ['uidprintstyle',['UIDPrintStyle',['../../base/classSteinberg_1_1FUID.html#a4c6d5af58eee71460b173f2a3fc16e83',1,'Steinberg::FUID']]],
   ['unit',['Unit',['../../vstsdk/classSteinberg_1_1Vst_1_1Unit.html#a50125d90c2d04510fdb684ba3fac21dd',1,'Steinberg::Vst::Unit::Unit(const String128 name, UnitID unitId, UnitID parentUnitId=kRootUnitId, ProgramListID programListId=kNoProgramListId)'],['../../vstsdk/classSteinberg_1_1Vst_1_1Unit.html#a74283874e8ea9c7f41dfdcf9ff43ee30',1,'Steinberg::Vst::Unit::Unit(const UnitInfo &amp;unit)']]],
