@@ -173,81 +173,81 @@ var NAVTREEINDEX5 =
 "vst2persistence_8h.html#ab373c1cff2f2f5cbb560d5631ca9cf11":[5,0,86,5],
 "vst2persistence_8h.html#ae40166dd2c8a5e7b724178bf1d8b4289":[5,0,86,2],
 "vst2persistence_8h.html#af4c57cb866e8a8343d790c6d60c8a21b":[5,0,86,4],
-"vst2wrapper_8cpp.html":[5,0,87],
-"vst2wrapper_8cpp.html#ab87c41720b6d7f3c416748ac5c28de0d":[5,0,87,0],
-"vst2wrapper_8h.html":[5,0,88],
-"vst2wrapper_8sdk_8cpp.html":[5,0,89],
-"vstaudioeffect_8cpp.html":[5,0,94],
-"vstaudioeffect_8h.html":[5,0,95],
-"vstaudioprocessoralgo_8h.html":[5,0,96],
-"vstaudioprocessoralgo_8h.html#a15c1c19c964ef2e7e86a9b3ffcf9e4c5":[5,0,96,6],
-"vstaudioprocessoralgo_8h.html#a18aea9feb58dbe1f6201eeee6c072155":[5,0,96,3],
-"vstaudioprocessoralgo_8h.html#a24782ecf71e6cf327e0614ec373624cc":[5,0,96,12],
-"vstaudioprocessoralgo_8h.html#a25ed939a301649331125f0929334df23":[5,0,96,21],
-"vstaudioprocessoralgo_8h.html#a26d0efd0ec8967f561d09ef4bcae7655":[5,0,96,9],
-"vstaudioprocessoralgo_8h.html#a462ca40a45befc344ea3de34256c067b":[5,0,96,13],
-"vstaudioprocessoralgo_8h.html#a4979d1f1ce8a6870d7bab7c0cce499dc":[5,0,96,10],
-"vstaudioprocessoralgo_8h.html#a4cb4ac5d134f87d28833172d318eee91":[5,0,96,5],
-"vstaudioprocessoralgo_8h.html#a6206b73e5b2a05df6f4c2ea49735ca45":[5,0,96,11],
-"vstaudioprocessoralgo_8h.html#a8321b46d3e8a41462d8b68c661568507":[5,0,96,22],
-"vstaudioprocessoralgo_8h.html#a84892f45159b0bd1836030284f9eefc7":[5,0,96,4],
-"vstaudioprocessoralgo_8h.html#a965e36149619ace13036a8a766bb0404":[5,0,96,8],
-"vstaudioprocessoralgo_8h.html#aa9dfbe077a3078558451ff526b305744":[5,0,96,1],
-"vstaudioprocessoralgo_8h.html#ab0290cfe659c7a4de89c7ef45af643a5":[5,0,96,15],
-"vstaudioprocessoralgo_8h.html#ab9a15d2a72d5500380bb5fa49551abf3":[5,0,96,18],
-"vstaudioprocessoralgo_8h.html#abdfc054d6e61b9fb841b38ba47645949":[5,0,96,0],
-"vstaudioprocessoralgo_8h.html#ac5416c9248a6b737903df6e7d35f67e3":[5,0,96,2],
-"vstaudioprocessoralgo_8h.html#ac727ec5263dbcfffe6796f9b5012fcea":[5,0,96,16],
-"vstaudioprocessoralgo_8h.html#aca95440bf753e70fe7a8a00d95e83f9a":[5,0,96,14],
-"vstaudioprocessoralgo_8h.html#acaec494e28f0a1988b0a247c29c6d7db":[5,0,96,19],
-"vstaudioprocessoralgo_8h.html#ad3fbbf9aba45d6d78acc406f7177ddd2":[5,0,96,17],
-"vstaudioprocessoralgo_8h.html#adf74545ab50d6cd580ca0c81cc5918b0":[5,0,96,7],
-"vstaudioprocessoralgo_8h.html#aff127ca5c383c8f60dfabf2e385e6478":[5,0,96,20],
-"vstbus_8cpp.html":[5,0,97],
-"vstbus_8h.html":[5,0,98],
-"vstbypassprocessor_8h.html":[5,0,99],
-"vstbypassprocessor_8h.html#aa38fb44000f5b68aae2850bafd0b8391":[5,0,99,3],
-"vstcomponent_8cpp.html":[5,0,100],
-"vstcomponent_8cpp.html#a659fcad9bdc947491c6e057f59eacae2":[5,0,100,0],
-"vstcomponent_8h.html":[5,0,101],
-"vstcomponent_8h.html#a659fcad9bdc947491c6e057f59eacae2":[5,0,101,0],
-"vstcomponentbase_8cpp.html":[5,0,102],
-"vstcomponentbase_8h.html":[5,0,103],
-"vsteditcontroller_8cpp.html":[5,0,104],
-"vsteditcontroller_8h.html":[5,0,105],
-"vsteventshelper_8h.html":[5,0,106],
-"vsteventshelper_8h.html#a3e5296d9f56910f7b76bb836eeaf3440":[5,0,106,3],
-"vsteventshelper_8h.html#a47ddebf598d6a776308246e7716deac0":[5,0,106,4],
-"vsteventshelper_8h.html#a5d111f2ca95494fd25050552be927eef":[5,0,106,5],
-"vsteventshelper_8h.html#a66467ea805dba72ceca57e81ef6fe007":[5,0,106,1],
-"vsteventshelper_8h.html#a7773e0a672be20e05b01258dcea10ddf":[5,0,106,6],
-"vsteventshelper_8h.html#a8107678cf9f7171d1e467b4d79c96956":[5,0,106,7],
-"vsteventshelper_8h.html#acee21ef070bcb18b50ed4b1376462ce7":[5,0,106,2],
-"vsteventshelper_8h.html#af6b5e0825fbe7c215d5e05b118ab2e1e":[5,0,106,0],
-"vstgui__win32__bundle__support_8cpp.html":[5,0,107],
-"vstgui__win32__bundle__support_8cpp.html#a5fe69fef877c637b191f7d45ad040849":[5,0,107,0],
-"vstgui__win32__bundle__support_8h.html":[5,0,108],
-"vstgui__win32__bundle__support_8h.html#a5fe69fef877c637b191f7d45ad040849":[5,0,108,0],
-"vstguieditor_8cpp.html":[5,0,109],
-"vstguieditor_8cpp.html#ab302317af2233cef9ab2bd2a2d89b60f":[5,0,109,1],
-"vstguieditor_8cpp.html#acfe0fc5dd43523202fab9c1ec6ef4e42":[5,0,109,2],
-"vstguieditor_8cpp.html#af8834087d8a239b18e64cce3a3198176":[5,0,109,0],
-"vstguieditor_8h.html":[5,0,110],
-"vstguieditor_8h.html#abadb0c7013f002aa8ce4dc4ede5174f4":[5,0,110,0],
-"vsthelpers_8h.html":[5,0,111],
-"vsthelpers_8h.html#a7f02c298f47c0db9090be5aacb05f57b":[5,0,111,0],
-"vstinitiids_8cpp.html":[5,0,112],
-"vstnoteexpressiontypes_8cpp.html":[5,0,115],
-"vstnoteexpressiontypes_8h.html":[5,0,116],
-"vstparameters_8cpp.html":[5,0,117],
-"vstparameters_8h.html":[5,0,118],
-"vstpresetfile_8cpp.html":[5,0,119],
-"vstpresetfile_8cpp.html#a1c0494fa27bea9e830204ab0451615c9":[5,0,119,2],
-"vstpresetfile_8cpp.html#a1d9350b127ef8ad03a8025e93853b433":[5,0,119,3],
-"vstpresetfile_8cpp.html#a5be931a78fa765babf69c7dc76e0c800":[5,0,119,1],
-"vstpresetfile_8cpp.html#a6abddc24208fd641b8776e4be24d3cad":[5,0,119,4],
-"vstpresetfile_8cpp.html#a9eb03817ce43297a3187ab5dc9f3340a":[5,0,119,5],
-"vstpresetfile_8cpp.html#aecb30226876947afe7079bc185597f0c":[5,0,119,0],
-"vstpresetfile_8h.html":[5,0,120],
-"vstpresetfile_8h.html#a235c00ee8509a0532c542fc91326849b":[5,0,120,7]
+"vstaudioeffect_8cpp.html":[5,0,91],
+"vstaudioeffect_8h.html":[5,0,92],
+"vstaudioprocessoralgo_8h.html":[5,0,93],
+"vstaudioprocessoralgo_8h.html#a15c1c19c964ef2e7e86a9b3ffcf9e4c5":[5,0,93,6],
+"vstaudioprocessoralgo_8h.html#a18aea9feb58dbe1f6201eeee6c072155":[5,0,93,3],
+"vstaudioprocessoralgo_8h.html#a24782ecf71e6cf327e0614ec373624cc":[5,0,93,12],
+"vstaudioprocessoralgo_8h.html#a25ed939a301649331125f0929334df23":[5,0,93,21],
+"vstaudioprocessoralgo_8h.html#a26d0efd0ec8967f561d09ef4bcae7655":[5,0,93,9],
+"vstaudioprocessoralgo_8h.html#a462ca40a45befc344ea3de34256c067b":[5,0,93,13],
+"vstaudioprocessoralgo_8h.html#a4979d1f1ce8a6870d7bab7c0cce499dc":[5,0,93,10],
+"vstaudioprocessoralgo_8h.html#a4cb4ac5d134f87d28833172d318eee91":[5,0,93,5],
+"vstaudioprocessoralgo_8h.html#a6206b73e5b2a05df6f4c2ea49735ca45":[5,0,93,11],
+"vstaudioprocessoralgo_8h.html#a8321b46d3e8a41462d8b68c661568507":[5,0,93,22],
+"vstaudioprocessoralgo_8h.html#a84892f45159b0bd1836030284f9eefc7":[5,0,93,4],
+"vstaudioprocessoralgo_8h.html#a965e36149619ace13036a8a766bb0404":[5,0,93,8],
+"vstaudioprocessoralgo_8h.html#aa9dfbe077a3078558451ff526b305744":[5,0,93,1],
+"vstaudioprocessoralgo_8h.html#ab0290cfe659c7a4de89c7ef45af643a5":[5,0,93,15],
+"vstaudioprocessoralgo_8h.html#ab9a15d2a72d5500380bb5fa49551abf3":[5,0,93,18],
+"vstaudioprocessoralgo_8h.html#abdfc054d6e61b9fb841b38ba47645949":[5,0,93,0],
+"vstaudioprocessoralgo_8h.html#ac5416c9248a6b737903df6e7d35f67e3":[5,0,93,2],
+"vstaudioprocessoralgo_8h.html#ac727ec5263dbcfffe6796f9b5012fcea":[5,0,93,16],
+"vstaudioprocessoralgo_8h.html#aca95440bf753e70fe7a8a00d95e83f9a":[5,0,93,14],
+"vstaudioprocessoralgo_8h.html#acaec494e28f0a1988b0a247c29c6d7db":[5,0,93,19],
+"vstaudioprocessoralgo_8h.html#ad3fbbf9aba45d6d78acc406f7177ddd2":[5,0,93,17],
+"vstaudioprocessoralgo_8h.html#adf74545ab50d6cd580ca0c81cc5918b0":[5,0,93,7],
+"vstaudioprocessoralgo_8h.html#aff127ca5c383c8f60dfabf2e385e6478":[5,0,93,20],
+"vstbus_8cpp.html":[5,0,94],
+"vstbus_8h.html":[5,0,95],
+"vstbypassprocessor_8h.html":[5,0,96],
+"vstbypassprocessor_8h.html#aa38fb44000f5b68aae2850bafd0b8391":[5,0,96,3],
+"vstcomponent_8cpp.html":[5,0,97],
+"vstcomponent_8cpp.html#a659fcad9bdc947491c6e057f59eacae2":[5,0,97,0],
+"vstcomponent_8h.html":[5,0,98],
+"vstcomponent_8h.html#a659fcad9bdc947491c6e057f59eacae2":[5,0,98,0],
+"vstcomponentbase_8cpp.html":[5,0,99],
+"vstcomponentbase_8h.html":[5,0,100],
+"vsteditcontroller_8cpp.html":[5,0,101],
+"vsteditcontroller_8h.html":[5,0,102],
+"vsteventshelper_8h.html":[5,0,103],
+"vsteventshelper_8h.html#a3e5296d9f56910f7b76bb836eeaf3440":[5,0,103,3],
+"vsteventshelper_8h.html#a47ddebf598d6a776308246e7716deac0":[5,0,103,4],
+"vsteventshelper_8h.html#a5d111f2ca95494fd25050552be927eef":[5,0,103,5],
+"vsteventshelper_8h.html#a66467ea805dba72ceca57e81ef6fe007":[5,0,103,1],
+"vsteventshelper_8h.html#a7773e0a672be20e05b01258dcea10ddf":[5,0,103,6],
+"vsteventshelper_8h.html#a8107678cf9f7171d1e467b4d79c96956":[5,0,103,7],
+"vsteventshelper_8h.html#acee21ef070bcb18b50ed4b1376462ce7":[5,0,103,2],
+"vsteventshelper_8h.html#af6b5e0825fbe7c215d5e05b118ab2e1e":[5,0,103,0],
+"vstgui__win32__bundle__support_8cpp.html":[5,0,104],
+"vstgui__win32__bundle__support_8cpp.html#a5fe69fef877c637b191f7d45ad040849":[5,0,104,0],
+"vstgui__win32__bundle__support_8h.html":[5,0,105],
+"vstgui__win32__bundle__support_8h.html#a5fe69fef877c637b191f7d45ad040849":[5,0,105,0],
+"vstguieditor_8cpp.html":[5,0,106],
+"vstguieditor_8cpp.html#ab302317af2233cef9ab2bd2a2d89b60f":[5,0,106,1],
+"vstguieditor_8cpp.html#acfe0fc5dd43523202fab9c1ec6ef4e42":[5,0,106,2],
+"vstguieditor_8cpp.html#af8834087d8a239b18e64cce3a3198176":[5,0,106,0],
+"vstguieditor_8h.html":[5,0,107],
+"vstguieditor_8h.html#abadb0c7013f002aa8ce4dc4ede5174f4":[5,0,107,0],
+"vsthelpers_8h.html":[5,0,108],
+"vsthelpers_8h.html#a7f02c298f47c0db9090be5aacb05f57b":[5,0,108,0],
+"vstinitiids_8cpp.html":[5,0,109],
+"vstnoteexpressiontypes_8cpp.html":[5,0,112],
+"vstnoteexpressiontypes_8h.html":[5,0,113],
+"vstparameters_8cpp.html":[5,0,114],
+"vstparameters_8h.html":[5,0,115],
+"vstpresetfile_8cpp.html":[5,0,116],
+"vstpresetfile_8cpp.html#a1c0494fa27bea9e830204ab0451615c9":[5,0,116,2],
+"vstpresetfile_8cpp.html#a1d9350b127ef8ad03a8025e93853b433":[5,0,116,3],
+"vstpresetfile_8cpp.html#a5be931a78fa765babf69c7dc76e0c800":[5,0,116,1],
+"vstpresetfile_8cpp.html#a6abddc24208fd641b8776e4be24d3cad":[5,0,116,4],
+"vstpresetfile_8cpp.html#a9eb03817ce43297a3187ab5dc9f3340a":[5,0,116,5],
+"vstpresetfile_8cpp.html#aecb30226876947afe7079bc185597f0c":[5,0,116,0],
+"vstpresetfile_8h.html":[5,0,117],
+"vstpresetfile_8h.html#a235c00ee8509a0532c542fc91326849b":[5,0,117,7],
+"vstpresetfile_8h.html#a6742d03aa1e93ba39b234d0ea402ee6d":[5,0,117,5],
+"vstpresetfile_8h.html#a6742d03aa1e93ba39b234d0ea402ee6da247a9a25a5fcf2b9a22b25874fdbb32b":[5,0,117,5,0],
+"vstpresetfile_8h.html#a6742d03aa1e93ba39b234d0ea402ee6da676f1a84ce41206b756a3baa743bb968":[5,0,117,5,5],
+"vstpresetfile_8h.html#a6742d03aa1e93ba39b234d0ea402ee6da6f13cbddc9f9d7754192b09f424abfb0":[5,0,117,5,3]
 };
