@@ -22,9 +22,6 @@ var searchData=
   ['visiblesavepresetviewcontroller',['visibleSavePresetViewController',['../classSteinberg_1_1Vst_1_1InterAppAudio_1_1PresetManager.html#a78c0dff72fd03c33fe4e2c3e4c9d4d62',1,'Steinberg::Vst::InterAppAudio::PresetManager']]],
   ['vst2persistence_2ecpp',['vst2persistence.cpp',['../vst2persistence_8cpp.html',1,'']]],
   ['vst2persistence_2eh',['vst2persistence.h',['../vst2persistence_8h.html',1,'']]],
-  ['vst2wrapper_2ecpp',['vst2wrapper.cpp',['../vst2wrapper_8cpp.html',1,'']]],
-  ['vst2wrapper_2eh',['vst2wrapper.h',['../vst2wrapper_8h.html',1,'']]],
-  ['vst2wrapper_2esdk_2ecpp',['vst2wrapper.sdk.cpp',['../vst2wrapper_8sdk_8cpp.html',1,'']]],
   ['vst2xchunk',['Vst2xChunk',['../namespaceVST3.html#ae40166dd2c8a5e7b724178bf1d8b4289',1,'VST3']]],
   ['vst2xprogram',['Vst2xProgram',['../structVST3_1_1Vst2xProgram.html',1,'VST3']]],
   ['vst2xstate',['Vst2xState',['../structVST3_1_1Vst2xState.html',1,'VST3']]],
